//
//  AnyLayoutExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.12.23.
//

import SwiftUI

struct AnyLayoutExampleView: View {
    @State private var isHorizontal: Bool = true
    
    var layout: AnyLayout {
        isHorizontal ? AnyLayout(HStackLayout()) : AnyLayout(VStackLayout())
    }
    
    var body: some View {
        VStack {
            if isHorizontal {
                HStack {
                   texts
                }
            } else {
                VStack {
                   texts
                }
            }
            
            layout {
                texts
            }
            
            Toggle(isHorizontal ? "horizontal" : "vertical",
                   isOn: $isHorizontal.animation(.easeInOut(duration: 2)))
                .padding()
        }
    }
    
    @ViewBuilder
    var texts: some View {
        Text("First Text")
            .padding()
            .background(Color.yellow)
        Text("Second Text")
            .padding()
            .background(Color.cyan)
        StateExampleView()
    }
}

fileprivate struct StateExampleView: View {
    @State private var text: String = ""
    var body: some View {
        TextField("Type something", text: $text)
            .textFieldStyle(.roundedBorder)
            .padding()
    }
}

#Preview {
    AnyLayoutExampleView()
}
