//
//  ConditionalViewModifierExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.12.23.
//

import SwiftUI

struct ConditionalViewModifierExampleView: View {
    
    @State private var hasBorder: Bool = true
    
    var body: some View {
        VStack(spacing: 20) {
            Text("Hello, World!")
                .padding(hasBorder ? 10 : 0)
                .border(hasBorder ? Color.indigo : Color.clear)
            
            Text("Hello, World!")
                .applyIf(hasBorder, transform: { view in
                    view
                        .padding()
                        .border(Color.indigo)
                })
            
            // don`t do that or you loss user input
            StateExampleView()
                .applyIf(hasBorder, transform: { view in
                    view
                        .padding()
                        .border(Color.indigo)
                })
                .padding()
            
            Toggle(hasBorder ? "show border" : "no border",
                   isOn: $hasBorder.animation(.easeInOut(duration: 2)))
            .fixedSize()
        }
    }
}

extension View {
    @ViewBuilder
    func applyIf<M: View>(_ condition: Bool, transform: (Self) -> M) -> some View {
        if condition {
            transform(self)
        } else {
            self
        }
    }
}

fileprivate struct StateExampleView: View {
    @State private var text: String = ""
    var body: some View {
        TextField("Type something", text: $text)
    }
}


#Preview {
    ConditionalViewModifierExampleView()
}
