//
//  EnvironmentContainerView.swift
//  LayoutProject
//
//  Created by Karin Prater on 30.11.23.
//

import SwiftUI

struct EnvironmentContainerView<Content> : View where Content : View {
    
    @Environment(\.containerTitle) var title
    let content: () -> Content
    
    init(@ViewBuilder content: @escaping () -> Content) {
        self.content = content
    }
    
    var body: some View {
        ZStack {
            RoundedRectangle(cornerRadius: 25.0)
                .fill(Color.cyan.gradient)
            
            VStack(alignment: .leading,
                   spacing: 10) {
                
                if let title {
                    Text(title)
                        .font(.title)
                        .bold()
                }
                
                content()
            }
                   .padding()
        }
        .aspectRatio(1, contentMode: .fit)
    }
}


extension EnvironmentValues {
    
    struct ContainerTitleKey: EnvironmentKey {
        static var defaultValue: String? = nil
    }
    
    var containerTitle: String? {
        get { self[ContainerTitleKey.self] }
        set { self[ContainerTitleKey.self] = newValue }
    }
}

extension View {
    func containerTitle(_ title: String) -> some View {
        self
            .environment(\.containerTitle, title)
    }
}

#Preview {
    VStack {
        EnvironmentContainerView {
            Text("this is inside")
        }
    }
    .containerTitle("Title")
    .padding()
}
