//
//  NavigationSplitViewExample.swift
//  LayoutProject
//
//  Created by Karin Prater on 29.11.23.
//

import SwiftUI

struct NavigationSplitViewExample: View {
    
    let inspirations = NatureInspiration.examples()
    @State private var selectedInspiration: NatureInspiration? = nil
    
    var body: some View {
        NavigationSplitView {
            List(inspirations,
                 selection: $selectedInspiration) { inspiration in
                InspirationRow(inspiration: inspiration)
                    .tag(inspiration)
            }
                 .navigationTitle("Inspirations")
            
        } detail: {
            if let selectedInspiration {
                SizeInspirationDetailView(inspiration: selectedInspiration)
            } else {
                ContentUnavailableView("Please select an inspiration", systemImage: "photo")
            }
        }
    }
}

fileprivate struct SizeInspirationDetailView: View {
    
    let inspiration: NatureInspiration
    
    var body: some View {
        SizeClassStack {
            ImageAspectView(imageName: inspiration.imageName,
                            frameAspectRatio: 1.5)
            
            VStack(alignment: .leading, spacing: 5) {
                Text(inspiration.name)
                    .font(.title)
                Text(inspiration.description)
            }
            .padding(12)
        }
        .edgesIgnoringSafeArea([.bottom, .leading])
    }
}

#Preview {
    NavigationSplitViewExample()
}
