//
//  ScaledMetricExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 30.11.23.
//

import SwiftUI

struct ScaledMetricExampleView: View {
    
    @ScaledMetric var padding: CGFloat = 10
    @ScaledMetric var cornerRadius: CGFloat = 5
    @ScaledMetric var lineWidth: CGFloat = 4
    
    @Environment(\.dynamicTypeSize) var typeSize
    
    var customSize: CGFloat {
        switch typeSize {
            case .xSmall: return 3
            case .small: return 4
            case .medium: return 5
            case .large: return 6
            case .xLarge, .xxLarge, .xxxLarge: return 7
            case .accessibility1: return 8
            case .accessibility2: return 9
            case .accessibility3: return 10
            case .accessibility4: return 11
            case .accessibility5: return 12
            @unknown default:
                return 7
        }
    }
    
    var body: some View {
        VStack(spacing: customSize) {
            Text("Hello, World!")
                .padding(padding)
                .background {
                    RoundedRectangle(cornerRadius: cornerRadius)
                        .stroke(Color.blue, lineWidth: lineWidth)
                }
            
            Text("Second text")
            
            Spacer()
        }
    }
}

#Preview {
    ScaledMetricExampleView()
}
