//
//  SizeClassExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 29.11.23.
//

import SwiftUI

struct SizeClassExampleView: View {
    
    @Environment(\.horizontalSizeClass) var horizontalSizeClass
    @Environment(\.verticalSizeClass) var verticalSizeClass
    
    var body: some View {
        VStack {
            HStack {
                Text("horizontal size class: ")
                Text(horizontalSizeClass == .regular ? "regular" : "compact")
            }
            
            HStack {
                Text("vertical size class: ")
                Text(verticalSizeClass == .regular ? "regular" : "compact")
            }
            
            if verticalSizeClass == .regular {
                Text("iPhone in portrait mode")
            } else {
                Text("iPhone is in landscape mode")
            }
            
            
            SizeClassStack {
                ResizableImageView(imageName: "leaves")
                Text("awesome text")
            }
        }
    }
}


struct SizeClassStack<Content: View>: View {
    
    let content: () -> Content
    @Environment(\.verticalSizeClass) var verticalSizeClass
    
    init(@ViewBuilder content: @escaping () -> Content) {
        self.content = content
    }
    
    var body: some View {
        switch verticalSizeClass {
            case .compact:
                HStack(alignment: .center,
                       spacing: 10,
                       content: content)
            case .regular:
                VStack(alignment: .center,
                       spacing: 10,
                       content: content)
                
            case .none:
                EmptyView()
            case .some(_):
                EmptyView()
        }
        
    }
}



#Preview {
    SizeClassExampleView()
}
