//
//  SizeThatFitsListView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.12.23.
//

import SwiftUI

struct SizeThatFitsListView: View {
    
    let notes = Note.examples()
    
    var body: some View {
        NavigationStack {
            List {
                ForEach(notes) { note in
                    NoteRow(note: note)
                }
            }
            .navigationTitle("Notes")
        }
    }
}

fileprivate struct NoteRow: View {
    let note: Note
    
    @Environment(\.dynamicTypeSize) var typeSize
    
    var body: some View {
        
        ViewThatFits {
            HStack {
                favIcon
                titleView
                Spacer()
                dateView
            }
            
            HStack(alignment: .firstTextBaseline) {
                favIcon
                VStack(alignment: .leading) {
                    titleView
                        .lineLimit(2)
                    dateView
                }
            }
        }
    }
    
    var dateView: some View {
        Text(note.creationDate.formatted(date: .abbreviated,
                                         time: typeSize.isAccessibilitySize ? .omitted : .shortened))
            .font(.caption)
            .foregroundStyle(.gray)
    }
    
    var favIcon: some View {
        Image(systemName: "heart.fill")
            .foregroundStyle(note.isFavorite ? .accent : .clear)
    }
    
    var titleView: some View {
        Text(note.title)
    }
}

#Preview {
    SizeThatFitsListView()
}
