//
//  ViewThatFitsInspirationDetailView.swift
//  LayoutProject
//
//  Created by Karin Prater on 04.12.23.
//

import SwiftUI

struct ViewThatFitsInspirationDetailView: View {
    let inspiration = NatureInspiration.example1()
    
    var body: some View {
        ViewThatFits(in: .horizontal) {
           LandscapeInspirationDetailView(inspiration: inspiration)
           PortraitInspirationDetailView(inspiration: inspiration)
        }
    }
}

fileprivate struct PortraitInspirationDetailView: View {
    let inspiration: NatureInspiration
    var body: some View {
        ScrollView {
            VStack {
                ImageInspirationDetailView(inspiration: inspiration)
                TextsInspirationDetailView(inspiration: inspiration)
            }
        }
    }
}

fileprivate struct LandscapeInspirationDetailView: View {
    let inspiration: NatureInspiration
    var body: some View {
        GeometryReader(content: { geometry in
            ScrollView {
                HStack {
                    ImageInspirationDetailView(inspiration: inspiration)
                        .frame(minHeight: geometry.size.height)
                    
                    TextsInspirationDetailView(inspiration: inspiration)
                }
            }
        })
        .frame(minWidth: 431)
    }
}

fileprivate struct TextsInspirationDetailView: View {
    let inspiration: NatureInspiration
    var body: some View {
        VStack(alignment: .leading, spacing: 5) {
            Text(inspiration.name)
                .font(.title)
            Text(inspiration.description)
        }
        .padding(12)
    }
}

fileprivate struct ImageInspirationDetailView: View {
    let inspiration: NatureInspiration
    var body: some View {
        ImageAspectView(imageName: inspiration.imageName,
                        frameAspectRatio: 1)
    }
}

#Preview {
    ViewThatFitsInspirationDetailView()
}

#Preview("Portrait", traits: .portrait, body: {
    PortraitInspirationDetailView(inspiration: NatureInspiration.example1())
       
})

#Preview("Landscape", traits: .landscapeLeft, body: {
    LandscapeInspirationDetailView(inspiration: NatureInspiration.example1())
        .fixedSize(horizontal: true, vertical: false)
})
