//
//  GeometryReaderExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 20.10.23.
//

import SwiftUI

struct GeometryReaderExampleView: View {
    
    let namespace: String = "namespace"
    
    var body: some View {
        VStack {
            Text("Hello, World!")
            
            GeometryReader(content: { geometry in
                VStack(spacing: 0) {
                    HStack(spacing: 10) {
                        Text("Content")
                            .frame(width: (geometry.size.width - 10) / 2,
                                   height: geometry.size.height / 2)
                            .background(Color.yellow)
                        Text("origin \(geometry.frame(in: .named(namespace)).minX) - \(geometry.frame(in: .named(namespace)).minY)")
                        
                            .frame(width: (geometry.size.width - 10) / 2,
                                   height: geometry.size.height / 2)
                            .background(Color.orange)
                    }
                    Image("dog_3")
                        .resizable()
                        .scaledToFill()
                        .frame(width: geometry.size.width / 2,
                               height: geometry.size.height / 2)
                        .clipped()
                }
                
            })
            
            .border(Color.black)
            .padding()
        }
        .coordinateSpace(name: namespace)
    }
}

fileprivate struct BadGeometryReaderExampleView: View {
    var body: some View {
        ScrollView {
            GeometryReader(content: { geometry in
                Image("dog_3")
                    .resizable()
                    .scaledToFill()
                    .frame(width: geometry.size.width,
                           height: geometry.size.width)
                    .clipped()
            })
           // .frame(idealHeight: geometry.size.width)
            
           
            Image("cat_1")
                .resizable()
                .scaledToFit()
        }
    }
}

fileprivate struct ImageGeometryReaderExampleView: View {
    
    let inspirations = NatureInspiration.examples()
    
    var body: some View {
        GeometryReader(content: { geometry in
            ScrollView {
                LazyVStack(spacing: 0) {
                    ForEach(inspirations) { inspiration in
                        Image(inspiration.imageName)
                            .resizable()
                            .scaledToFill()
                            .frame(width: geometry.size.width,
                                   height: geometry.size.width / 2)
                            .clipped()
                        
                    }
                }
            }
        })
    }
}

#Preview {
    GeometryReaderExampleView()
}

#Preview("Bad example") {
    BadGeometryReaderExampleView()
}

#Preview("Image Scrollview") {
    ImageGeometryReaderExampleView()
}
