//
//  GeometryReaderInspirationListView.swift
//  LayoutProject
//
//  Created by Karin Prater on 17.10.23.
//


import SwiftUI

struct GeometryReaderInspirationListView: View {
    
    let inspirations = NatureInspiration.examples()
    
    var body: some View {
        GeometryReader(content: { geometry in
            ScrollView {
                LazyVStack(alignment: .leading, spacing: 10, content: {
                    ForEach(inspirations) { inspiration in
                        
                        HStack(alignment: .top, spacing: 10) {
                            // how do i get this image to take up 1/3 of the row
                            ImageAspectView(imageName: inspiration.imageName,
                                            frameAspectRatio: 1,
                                            cornerRadius: 15)
                            .frame(width: geometry.size.width * 0.3)
                            
                            VStack(alignment: .leading, spacing: 5) {
                                Text(inspiration.name)
                                Text(inspiration.description)
                                    .font(.caption)
                                    .lineLimit(4)
                            }
                            .padding(.vertical, 12)
                        }
                    }
                })
                .padding()
            }
        })
    }
}

struct ContainerRelativeInspirationListView: View {
    let inspirations = NatureInspiration.examples()
    var body: some View {
        ScrollView {
            LazyVStack(alignment: .leading, spacing: 10, content: {
                ForEach(inspirations) { inspiration in
                    InspirationRow(inspiration: inspiration)
                }
            })
            .padding()
        }
    }
}

#Preview("GeometryReader") {
    GeometryReaderInspirationListView()
}

#Preview("ContainerRelativeFrame") {
    ContainerRelativeInspirationListView()
}
