//
//  InspirationDetailView.swift
//  LayoutProject
//
//  Created by Karin Prater on 20.10.23.
//

import SwiftUI

struct InspirationDetailView: View {
    
    let inspiration: NatureInspiration
    
    var body: some View {
        GeometryStack {
            ImageAspectView(imageName: inspiration.imageName,
                            frameAspectRatio: 1)
            
            VStack(alignment: .leading, spacing: 5) {
                Text(inspiration.name)
                    .font(.title)
                Text(inspiration.description)
            }
            .padding(12)
        }
        .edgesIgnoringSafeArea([.bottom, .leading])
    }
}

struct GeometryStack<Content: View>: View {
    
    let content: () -> Content
    let limit: CGFloat
    
    init(limit: CGFloat = 431, 
         @ViewBuilder content: @escaping () -> Content) {
        self.limit = limit
        self.content = content
    }
    
    var body: some View {
        GeometryReader(content: { geometry in
            ScrollView {
                let layout = geometry.size.width > limit  ?
                AnyLayout(HStackLayout(alignment: .center, spacing: 20)) : AnyLayout(VStackLayout())
                
                layout(content)
            }
            
        })
    }
}


#Preview {
    InspirationDetailView(inspiration: .example1())
}
