/*
See LICENSE folder for this sample’s licensing information.

example from Apple demo project Food Truck App
 
Abstract:
The social feed card showing in the Truck view.
*/

import SwiftUI

struct SocialFeedTag: Identifiable, Hashable {
    let title: String
    let icon: String
    let id = UUID()
}

struct TruckSocialFeedCard: View {
    private let tags: [SocialFeedTag] = [SocialFeedTag(title: "Warm up", icon: "scribble"),
                                         SocialFeedTag(title: "Room Temperature", icon: "circle"),
                                         SocialFeedTag(title: "Rainbow Sprinkles", icon: "circle.fill"),
                                         SocialFeedTag(title: "Donut vs Doughnut", icon: "folder"),
                                         SocialFeedTag(title: "Carrots", icon: "text.bubble"),
                                         SocialFeedTag(title: "Dairy Free", icon: "pencil.tip"),
                                         SocialFeedTag(title: "Gluten Free", icon: "circle")]
    var body: some View {
        VStack(alignment: .leading, spacing: 16) {
            Text("Post Message")
                .font(.title3)
            
            FlowLayout(alignment: .leading){
                ForEach(tags) { tag in
                    Label(tag.title, systemImage: tag.icon)
                        .labelStyle(.socialFeedTag)
                }
            }
            #if os(iOS)
            .backgroundStyle(Color(uiColor: .secondarySystemBackground))
            #endif
            
            Spacer()
        }
        .padding()
    }
}

extension LabelStyle where Self == SocialFeedTagLabelStyle {
    static var socialFeedTag: SocialFeedTagLabelStyle {
        SocialFeedTagLabelStyle()
    }
}

struct SocialFeedTagLabelStyle: LabelStyle {
    @ScaledMetric(relativeTo: .footnote) private var iconWidth = 14.0
    
    func makeBody(configuration: Configuration) -> some View {
        HStack {
            configuration.icon
                .foregroundColor(.secondary)
                .frame(width: iconWidth)
            configuration.title
        }
        .padding(6)
        .background(in: RoundedRectangle(cornerRadius: 5, style: .continuous))
        .compositingGroup()
        .shadow(radius: 1)
        .font(.caption)
    }
}


struct TruckSocialFeedCard_Previews: PreviewProvider {
    static var previews: some View {
        TruckSocialFeedCard()
    }
}

