//
//  AspectRatioImageCollectionHStack.swift
//  LayoutProject
//
//  Created by Karin Prater on 17.10.23.
//

import SwiftUI


@available(iOS 16.0, macOS 13.0, tvOS 16.0, watchOS 9.0, *)
struct AspectRatioImageCollectionHStack: Layout {
    
    let spacing: CGFloat
    
    func sizeThatFits(proposal: ProposedViewSize, subviews: Subviews, cache: inout ()) -> CGSize {
        let width = proposal.width ?? 0
        let height = calculateHeight(proposal: proposal, subviews: subviews)
        
        return CGSize(width: width, height: height)
    }
    
    func placeSubviews(in bounds: CGRect, proposal: ProposedViewSize, subviews: Subviews, cache: inout ()) {
        guard !subviews.isEmpty else { return }
        
        let subviewHeight = calculateHeight(proposal: proposal, subviews: subviews)
        var x = bounds.minX
        
        for (index, subView) in subviews.enumerated() {
            let viewAspectRatio = subView[ImageAspectRatio.self]
            let subviewWidth = subviewHeight * viewAspectRatio
            let placementProposal = ProposedViewSize(width: subviewWidth, height: subviewHeight)
            
            subviews[index].place(at: CGPoint(x: x + subviewWidth / 2, y: bounds.midY),
                                  anchor: .center,
                                  proposal: placementProposal)
            x += subviewWidth + spacing
        }
    }
    
    func calculateHeight(proposal: ProposedViewSize, subviews: Subviews) -> CGFloat {
        let subViewSizes = subviews.map { $0.sizeThatFits(.unspecified) }
       
        let subViewAspectRatios = subviews.map { subview in
            subview[ImageAspectRatio.self]
        }
        
        let sumSubViewAspectRatios = subViewAspectRatios.reduce(0) { $0 + $1 }
        let totalSpacing = spacing * CGFloat(subviews.count - 1)
        let availablWidth = proposal.width ?? 0
        
        return (availablWidth - totalSpacing) / sumSubViewAspectRatios
    }
}



/// A key that the layout uses to read the rank for a subview.
private struct ImageAspectRatio: LayoutValueKey {
    static let defaultValue: CGFloat = 1
}

extension View {
    /// Sets the rank layout value on a view.
    func imageAspectRatio(_ value: CGFloat) -> some View {
        layoutValue(key: ImageAspectRatio.self, value: value)
    }
}
