//
//  AsyncImageCollectionView.swift
//  LayoutProject
//
//  Created by Karin Prater on 20.10.23.
//

import SwiftUI

struct AsyncImageCollectionView: View {
    
    @StateObject var photoLoader =  PicsumPhotoLoader(page: 4, photosPerPage: 20) // PicsumPhotoLoader.preview() //
    @Environment(\.displayScale) var scale
    
    let spacing: CGFloat = 1
    
    var body: some View {
        ScrollView {
            LazyVStack(spacing: spacing) {
                ForEach(photoLoader.photoRows, id: \.self) { row in
                    AspectRatioImageCollectionHStack(spacing: spacing) {
                        ForEach(row) { photo in
                            AspectRatioSizedAsyncImage(photo: photo)
                        }
                    }
                }
            }
            
            /*
            if photoLoader.photos.count > 3 {
                AspectRatioImageCollectionHStack(spacing: spacing) {
                    AspectRatioSizedAsyncImage(photo: photoLoader.photos[0])
                    AspectRatioSizedAsyncImage(photo: photoLoader.photos[1])
                    AspectRatioSizedAsyncImage(photo: photoLoader.photos[2])
                }
            }
             */
        }
    }
}

fileprivate struct AspectRatioSizedAsyncImage: View {
    
    let photo: PicsumPhoto
    let baseURLString = "https://picsum.photos/id/"
    @Environment(\.displayScale) var scale
    
    var body: some View {
        GeometryReader(content: { geometry in
            AsyncImage(url: url(in: geometry.size.width),
                       scale: scale,
                       transaction: .init(animation: .bouncy)) { phase in
                switch phase {
                    case .empty:
                        ZStack {
                            Color.gray
                            ProgressView()
                        }
                    case .success(let image):
                        image.resizable()
                            .scaledToFit()
                    case .failure(let error):
                        Text(error.localizedDescription)
                        // use placeholder for production app
                    @unknown default:
                        Text("default")
                }
            }
        })
        .imageAspectRatio(photo.aspectRatio)
    }
    
    func url(in width: CGFloat) -> URL? {
        let imageWidth = width * scale
        let imageHeight = imageWidth / photo.aspectRatio
        let urlString = "\(baseURLString)\(photo.id)/\(Int(imageWidth))/\(Int(imageHeight))"
        return URL(string: urlString)
    }
}

#Preview {
    AsyncImageCollectionView()
}
