//
//  ImageCollectionHStack.swift
//  LayoutProject
//
//  Created by Karin Prater on 17.10.23.
//

import SwiftUI

// do the same for vstack column

/*
let viewSize = subview.sizeThatFits(.unspecified) // ideal size
subview.sizeThatFits(.zero) // minimum size
subview.sizeThatFits(.infinity) // maximum size
*/

@available(iOS 16.0, macOS 13.0, tvOS 16.0, watchOS 9.0, *)
struct ImageCollectionHStack: Layout {
    
    let spacing: CGFloat
    
    func sizeThatFits(proposal: ProposedViewSize, subviews: Subviews, cache: inout ()) -> CGSize {
        let width = proposal.width ?? 0
        let height = calculateHeight(proposal: proposal, subviews: subviews)
        
        return CGSize(width: width, height: height)
    }
    
    func placeSubviews(in bounds: CGRect, proposal: ProposedViewSize, subviews: Subviews, cache: inout ()) {
        guard !subviews.isEmpty else { return }
        
        let subviewHeight = calculateHeight(proposal: proposal, subviews: subviews)
        var x = bounds.minX
        
        for (index, subView) in subviews.enumerated() {
            let viewSize = subView.sizeThatFits(.unspecified)
            let subviewWidth = subviewHeight * viewSize.width / viewSize.height
            let placementProposal = ProposedViewSize(width: subviewWidth, height: subviewHeight)
            
            subviews[index].place(at: CGPoint(x: x + subviewWidth / 2, y: bounds.midY),
                                  anchor: .center,
                                  proposal: placementProposal)
            x += subviewWidth + spacing
        }
    }
    
    func calculateHeight(proposal: ProposedViewSize, subviews: Subviews) -> CGFloat {
        
        let subViewSizes = subviews.map { $0.sizeThatFits(.unspecified) }
        let subViewAspectRatios = subViewSizes.map { $0.width / $0.height }
        let sumSubViewAspectRatios = subViewAspectRatios.reduce(0) { $0 + $1 }
        
        let totalSpacing = spacing * CGFloat(subviews.count - 1)
        
        let availablWidth = proposal.width ?? 0
        
        return (availablWidth - totalSpacing) / sumSubViewAspectRatios
    }
}
