//
//  RadialLayoutExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 20.10.23.
//

import SwiftUI

struct RadialLayoutExampleView: View {
    
    @State private var pets = [
        Pet(type: .cat,
            votes: 25,
            images: ["cat_1", "cat_2", "cat_3", "cat_4"],
            facts: ["Cats have excellent night vision.", "Cats use their whiskers to measure openings."]),
        Pet(type: .dog,
            votes: 11,
            images: ["dog_1", "dog_2", "dog_3", "dog_4"],
            facts: ["Dogs have an extraordinary sense of smell.", "Dogs are known for their loyalty."]),
        Pet(type: .fish,
            votes: 5,
            images: ["fish_1", "fish_2", "fish_3", "fish_4"],
            facts: ["Fish come in many shapes, sizes, and colors.", "Some fish can change their gender as they age."])
    ]
    
    var body: some View {
        VStack {
            Text("Vote for your favorite pet")
            
            MyRadialLayout() {
                ForEach(pets) { pet in
                    PetBubbleView(pet: pet, allPets: pets)
                        
                }
            }
            .background(Circle().stroke(Color.indigo).padding(50))
            
            
            Grid(alignment: .leading, horizontalSpacing: 30) {
                ForEach(pets) { pet in
                    GridRow(alignment: .firstTextBaseline) {
                   
                        Text(pet.type.displayName)
                            .font(.title)
                          
                        Text("votes: \(pet.votes)")
                        
                       
                        Button("upvote") {
                            withAnimation {
                                if let index = pets.firstIndex(of: pet) {
                                    pets[index].votes += 1
                                }
                            }
                        }
                        .buttonStyle(.bordered)
                    }
                }
            }
        }
    }
}

fileprivate struct PetBubbleView: View {
    let pet: Pet
    let allPets: [Pet]
    
    var body: some View {
        Text(emoji(for:pet))
            .font(.system(size: 70))
            .padding()
            .background(Circle().fill(.indigo).shadow(radius: 5))
            .rank(rank(pet))
    }
    
    func emoji(for pet: Pet) -> String {
        switch pet.type {
            case .cat: "😸"
            case .dog: "🐶"
            case .fish: "🐠"
            case .horse: "🐴"
        }
    }
    
    func rank(_ pet: Pet) -> Int {
        allPets.reduce(1) { $0 + (($1.votes > pet.votes) ? 1 : 0) }
    }
}


#Preview {
    RadialLayoutExampleView()
}
