//
//  BoundsMeasurmentExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 20.10.23.
//

import SwiftUI

struct BoundsMeasurmentExampleView: View {
    
    @State private var bounds = CGRect.zero
    
    var body: some View {
        VStack {
            Image(.candies)
                .resizable()
                .scaledToFit()
                .frame(width: 350)
                .measureBounds(bounds: $bounds, namespace: "dummy namespace")
            
            Text("size: \(bounds.width)")
        }
    }
}

struct BoundsMeasurment: ViewModifier {
    
    @Binding var bounds: CGRect
    let namespace: String
    
    func body(content: Content) -> some View {
        content
            .background {
                GeometryReader(content: { geometry in
                    Color.clear
                        .preference(key: BoundsPreferenceKey.self, value: geometry.frame(in: .named(namespace)))
                })
            }
            .onPreferenceChange(BoundsPreferenceKey.self, perform: { value in
                self.bounds = value
            })
    }
}

extension View {
    func measureBounds(bounds: Binding<CGRect>,
                       namespace: String) -> some View {
        self.modifier(BoundsMeasurment(bounds: bounds,
                                   namespace: namespace))
    }
}


struct BoundsPreferenceKey: PreferenceKey {
    static var defaultValue: CGRect = .zero
    
    static func reduce(value: inout CGRect, nextValue: () -> CGRect) {
        value = nextValue()
    }
}

#Preview {
    BoundsMeasurmentExampleView()
}
