//
//  PreferenceContainerView.swift
//  LayoutProject
//
//  Created by Karin Prater on 20.10.23.
//

import SwiftUI

struct PreferenceContainerView<Content> : View where Content : View {
    
    @State private var title: String? = nil
    let content: () -> Content
    
    init(@ViewBuilder content: @escaping () -> Content) {
        self.content = content
    }
    
    var body: some View {
        ZStack {
            RoundedRectangle(cornerRadius: 25.0)
                .fill(Color.cyan.gradient)
            
            VStack(alignment: .leading,
                   spacing: 10) {
                
                if let title {
                    Text(title)
                        .font(.title)
                        .bold()
                }
                
                content()
            }
            .padding()
        }
        .aspectRatio(1, contentMode: .fit)
        .onPreferenceChange(StringPreferenceKey.self, perform: { value in
            self.title = value
        })
    }
}

struct StringPreferenceKey: PreferenceKey {
   static var defaultValue: String? = nil
    
    static func reduce(value: inout String?, nextValue: () -> String?) {
        guard let nextValue = nextValue() else { return }
        value = nextValue
    }
}

extension View {
    func myContainerTitle(_ title: String) -> some View  {
        self.preference(key: StringPreferenceKey.self, value: title)
    }
}


#Preview {
    PreferenceContainerView{
        Text("First Text")
            .myContainerTitle("First")
        
        HStack {
            Text("Container with Preferences")
                .myContainerTitle("Second title")
            
            VStack {
                Text("Child")
                   // .myContainerTitle("Child title")
            }
        }
    }
    .padding()
}
