//
//  BindingForeachExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 22.10.23.
//

import SwiftUI

struct BindingForeachExampleView: View {
    
    @State var fruits = [Fruit(name: "apple"),
                         Fruit(name: "banana"),
                         Fruit(name: "cherry"),
                         Fruit(name: "kiwi"),
                         Fruit(name: "cherry")]
    
    var body: some View {
        VStack(alignment: .leading) {
            
            Text("What colors have these Fruits?")
                .font(.title)
            
            ForEach($fruits) { $fruit in
                HStack {
                    Toggle("isFavorite", 
                           isOn: $fruit.isFavorite)
                    .toggleStyle(FavoriteToggleStyle())
                    TextField("Fruit", text: $fruit.name)
                    
                    ColorPicker(selection: $fruit.color) {
                        Text("Color")
                    }
                    .labelsHidden()
                }
            }
            
            Divider()
                .padding(.vertical)
            
            ForEach(fruits.filter({ $0.isFavorite })) { fruit in
                HStack {
                    Text(fruit.name)
                    fruit.color
                        .frame(height: 20)
                }
            }
            
            Spacer()
        }
        .padding()
        
    }
}

struct FavoriteToggleStyle: ToggleStyle {
    func makeBody(configuration: Configuration) -> some View {
        Button(action: {
            configuration.isOn.toggle()
        }) {
            Image(systemName: configuration.isOn ? "heart.fill" : "heart")
                .foregroundColor(.accentColor)
                .font(.system(size: 24))
        }
    }
}


#Preview {
    BindingForeachExampleView()
}
