//
//  ForEachExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 22.10.23.
//

import SwiftUI

struct ForEachExampleView: View {
    
    let fruits = ["apple", "banana", "peach", "kiwi"]
    
    var body: some View {
        VStack {
            HStack {
                Text("My Fruits: ")
                
                ForEach(fruits, id: \.self) { fruit in
                    Text(fruit)
                }
            }
            
            Divider()
            
            VStack {
                ForEach(0..<10) { index in
                    Text("index \(index)")
                }
            }
            
            Divider()
            
            ForEach(Array(fruits.enumerated()),
                    id: \.element) { index, fruit in
                Text("\(index + 1). \(fruit)")
            }
            
        }
    }
}

fileprivate struct UnorderedDataView: View {
    
    let numberDictionary: [Int: String] = [1: "One", 
                                           2: "Two",
                                           3: "Three"]
    @State private var uniqueNumbers: Set = [1,2,3,4,5]
    
    @State private var isForwardSorted: Bool = true
    
    var sortedUniqueNumbers: [Int] {
        if isForwardSorted {
            uniqueNumbers.sorted()
        } else {
            uniqueNumbers.sorted { $0 > $1 }
        }
    }
    
    var body: some View {
        VStack {
            
            ForEach(numberDictionary.keys.sorted(), id: \.self) { key in
                Text("\(key) with value \(numberDictionary[key] ?? "")")
            }
            
            Divider()
            
            HStack {
                VStack {
                    ForEach(Array(uniqueNumbers), id: \.self) { number in
                        Text("number \(number)")
                    }
                }
                VStack {
                    ForEach(sortedUniqueNumbers, id: \.self) { number in
                        Text("number \(number)")
                    }
                }
            }
            
            Button(action: {
                withAnimation {
                    let max = uniqueNumbers.max() ?? 0
                    uniqueNumbers.insert(max + 1)
                }
            }, label: {
                Text("Add a number")
            })
            .buttonStyle(CustomButtonStyle())
            
            Toggle(isForwardSorted ? "Forward" : "Reversed",
                   isOn: $isForwardSorted.animation())
        }
        .padding()
    }
}



#Preview {
    ForEachExampleView()
}

#Preview("Set and Dictionary", body: {
    UnorderedDataView()
})
