//
//  ForeachModelExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 22.10.23.
//

import SwiftUI

struct Fruit: Identifiable {
    var name: String
    var color: Color
    var isFavorite: Bool
    
    let id: UUID
    //var id: String { name }
    
    init(name: String,
         color: Color = .yellow,
         isFavorite: Bool = false) {
        self.name = name
        self.color = color
        self.isFavorite = isFavorite
        self.id = UUID()
    }
}

struct ForeachModelExampleView: View {
    
    @State var fruits = [Fruit(name: "apple"),
                         Fruit(name: "banana"),
                         Fruit(name: "kiwi"),
                         Fruit(name: "cherry")]
    @State private var text: String = ""
    @State private var color: Color = Color.yellow
    
    var body: some View {
        VStack(spacing: 20) {
            Text("Your Fruits")
                .font(.title)
            
            HStack {
                TextField("Fruit", text: $text)
                    .textFieldStyle(.roundedBorder)
                ColorPicker("Color", selection: $color)
                    .labelsHidden()
                Button(action: {
                    let newFruit = Fruit(name: text, color: color)
                    fruits.append(newFruit)
                    text = ""
                }, label: {
                    Label("Add", systemImage: "plus")
                })
                .buttonStyle(.bordered)
            }
            
            Divider()
            
            ForEach(fruits) { fruit in
                HStack {
                    Text(fruit.name)
                    fruit.color
                        .frame(height: 20)
                }
            }
        }
        .padding()
    }
}

#Preview {
    ForeachModelExampleView()
}
