//
//  ImageAsyncGalleryView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.11.23.
//

import SwiftUI

struct ImageAsyncGalleryView: View {
    
    @StateObject private var photoLoader = PicsumPhotoLoader(page: 3, photosPerPage: 20)
    
    var body: some View {
        ScrollView {
            LazyVStack(spacing: 0) {
                ForEach(photoLoader.photos) {
                    PicsumPhotoImage(photo: $0)
                }
            }
        }
    }
}

struct StrutteringImageAsyncGalleryView: View {
    
    @StateObject private var photoLoader = PicsumPhotoLoader(page: 3, photosPerPage: 20)
    @Environment(\.displayScale) var scale
    
    var body: some View {
        GeometryReader { geometry in
            ScrollView {
                LazyVStack(spacing: 0) {
                    ForEach(photoLoader.photos) { photo in
                        AsyncImage(url: url(in: geometry.size.width, photo: photo),
                                   scale: 3,
                                   transaction: .init(animation: .easeIn(duration: 0.4))) { phase in
                            switch phase {
                                case .empty:
                                    ZStack {
                                        Color.gray
                                        ProgressView()
                                    }
                                    .frame(height: 100)
                                case .success(let image):
                                    image
                                        .resizable()
                                        .scaledToFit()
                                case .failure(let error):
                                    Text(error.localizedDescription)
                                        .frame(height: 50)
                                    // use placeholder for production app
                                @unknown default:
                                    fatalError()
                            }
                        }
                    }
                }
            }
        }
    }
    
    func url(in width: CGFloat, photo: PicsumPhoto) -> URL? {
        let imageWidth = Int(width * scale)
        let imageHeight = Int(width * scale / photo.aspectRatio)
        let urlString = "https://picsum.photos/id/\(photo.id)/\(imageWidth)/\(imageHeight)"
        return URL(string: urlString)
    }
}



#Preview {
    ImageAsyncGalleryView()
}

#Preview("Stuttering") {
    StrutteringImageAsyncGalleryView()
}
