//
//  WaterfallImageGridExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 28.08.2023.
//

import SwiftUI

struct WaterfallImageGridExampleView: View {
    
    let inspirations = NatureInspiration.examples()
    let rightInspirations = NatureInspiration.examplesDifferentSizeImages()
    let spacing: CGFloat = 2
    
    var body: some View {
        ScrollView {
            HStack(alignment: .top, spacing: spacing) {
                LazyVStack(spacing: spacing) {

                    ForEach(rightInspirations.reversed()) { inspiration in
                       // Color.red.frame(height: 100)
                        ImageView(assetName: inspiration.imageName)
                    }
                }
                
                LazyVStack(spacing: spacing) {
                    
                    ForEach(rightInspirations) { inspiration in
                        ImageView(assetName: inspiration.imageName)
                    }
                }
              //  .frame(width: 150)
                .containerRelativeFrame(.horizontal) { length, axis in
                    length * 0.4
                }
            }
        }
    }
}

fileprivate struct ImageView: View {
    let assetName: String
    
    init(assetName: String) {
      //  print("create image - \(assetName)")
        self.assetName = assetName
    }
    
    var body: some View {
        Image(assetName)
            .resizable()
            .scaledToFit()
    }
}

/*
 infinit scolling
 onapper - last row or placeholder
 ListItemRowView(item: item)
                   .onAppear { viewModel.requestMoreItemsIfNeeded(index: index) }
 .task modifier
 
 use scrollposion
 */

struct LazyWaterfallImageGridExampleView: View {
    
    @StateObject var firstPhotoLoader = PicsumPhotoLoader(page: 6)
    @StateObject var secondPhotoLoader = PicsumPhotoLoader(page: 4)
    
    let spacing: CGFloat = 2
    
    var body: some View {
        ScrollView {
            HStack(alignment: .top, spacing: spacing) {
                LazyVStack(spacing: spacing) {
                    ForEach(firstPhotoLoader.photos) { photo in
                        PicsumPhotoImage(photo: photo)
                    }
                }
                
                LazyVStack(spacing: spacing) {
                    ForEach(secondPhotoLoader.photos) { photo in
                        PicsumPhotoImage(photo: photo)
                    }
                }
            }
        }
    }
}


#Preview {
    WaterfallImageGridExampleView()
}

#Preview("web images") {
    LazyWaterfallImageGridExampleView()
}
