//
//  InspirationColumnExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.11.23.
//

import SwiftUI

struct InspirationColumnExampleView: View {
    
    let inspirations = NatureInspiration.examples()
    
    var body: some View {
        ScrollView {
            LazyVGrid(columns: [GridItem(.adaptive(minimum: 300), spacing: 10)]) {
                ForEach(inspirations) { inspiration in
                    InspirationRowView(inspiration: inspiration)
                }
            }
            .padding()
        }
       
    }
}


struct LargeInspirationColumnExampleView: View {
    
    let inspirations = NatureInspiration.examples()
    let columns = [GridItem(.adaptive(minimum: 250),
                            spacing: 10)]
    var body: some View {
        ScrollView {
            LazyVGrid(columns: columns, 
                      alignment: .leading,
                      spacing: 10) {
                ForEach(inspirations) { inspiration in
                    Image(inspiration.imageName)
                        .resizable()
                        .scaledToFit()
                        .clipShape(RoundedRectangle(cornerRadius: 5))
                    
                    VStack(alignment: .leading, spacing: 5) {
                        Text(inspiration.name)
                            .font(.title2)
                        Text(inspiration.description)
                    }
                    .padding(.bottom)
                    .padding(.vertical)
                    .padding(.leading, 5)
                }
            }
            .padding()
        }
       
    }
}

#Preview {
    InspirationColumnExampleView()
}

#Preview {
    LargeInspirationColumnExampleView()
}
