//
//  LazyVGridExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.11.23.
//

import SwiftUI

struct LazyVGridExampleView: View {
    
    let emojis = Emoji.examples()
    
    var body: some View {
        ScrollView {
            LazyVGrid(columns: [GridItem(.adaptive(minimum: 80),
                                         spacing: 10)],
                      alignment: .center,
                      spacing: 10, content: {
                ForEach(emojis) {
                    EmojiView(emoji: $0)
                }
            })
            .padding()
        }
    }
}

struct LazyVGridFlexibleExampleView: View {
    
    let emojis = Emoji.examples()
    
    var body: some View {
        GeometryReader { geometry in
            ScrollView {
                LazyVGrid(columns: columns(width: geometry.size.width),
                          alignment: .center,
                          spacing: 10, content: {
                    ForEach(emojis) {
                        EmojiView(emoji: $0)
                    }
                })
                .padding()
            }
        }
    }
    
    func columns(width: CGFloat) -> [GridItem] {
        
        let columnCount = width < 450 ? 3 : 6
        
        return Array(repeating: GridItem(.flexible(minimum: 70, maximum: 150), spacing: 10, alignment: .top), count: columnCount)
    }
}

struct LazyVGridFixedExampleView: View {
    
    let emojis = Emoji.examples()
    
    let columns = Array(repeating: GridItem(.fixed(150)), count: 5)
    
    var body: some View {
        ScrollView([.horizontal, .vertical]) {
            LazyVGrid(columns: columns,
                      alignment: .center,
                      spacing: 10, content: {
                ForEach(emojis) {
                    EmojiView(emoji: $0)
                }
            })
            .padding()
        }
    }
}


#Preview("Adaptive") {
    LazyVGridExampleView()
}

#Preview("Flexible") {
    LazyVGridFlexibleExampleView()
}

#Preview("Fixed") {
    LazyVGridFixedExampleView()
}
