//
//  BackgroundExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.09.2023.
//

import SwiftUI

struct BackgroundExampleView: View {
    var body: some View {
        VStack {
            Text("Hello, World!")
                .padding()
                .background {
                    Color.cyan
                }
            
            Text("Cats are awesome")
                .padding()
                .background {
                    Image("abstract-pool-water")
                        .resizable()
                        .scaledToFill()
                }
                .clipped()
            
            Text("More")
                .padding(.horizontal)
                .background {
                    Capsule().fill(Color.cyan.gradient)
                }
            
        }
    }
}

fileprivate struct SuperHeroView: View {
    let superhero = SuperHero.example2
    var body: some View {
        ResizableImageView(imageName: superhero.imageName)
            .padding([.leading, .top])
            .background(alignment: .topLeading) {
                Text(superhero.name)
                    .font(.largeTitle)
                    .bold()
                    .foregroundStyle(.white)
                    .padding()
            }
            .background(
                RoundedRectangle(cornerRadius: 15)
                    .fill(Color.cyan.gradient)
            )
            .compositingGroup()
            .shadow(radius: 10)
            .padding()
    }
}

fileprivate struct SuperHeroHeaderView: View {
    let superhero = SuperHero.example
    var body: some View {
        VStack {
            
            ResizableImageView(imageName: superhero.imageName)
            
            Text(superhero.name)
                .font(.largeTitle)
                .bold()
                .foregroundStyle(.white)
                .padding()
            
            Text(superhero.biography)
            
            Spacer()
        }
       /*
        .background {
            Color.cyan
                .edgesIgnoringSafeArea(.all)
        }
        */
        .background(Color.cyan, ignoresSafeAreaEdges: .bottom)
        
    }
}

#Preview {
    BackgroundExampleView()
}

#Preview("Superhero", body: {
    SuperHeroView()
})

#Preview("Superhero Header", body: {
    SuperHeroHeaderView()
})
