//
//  ColorExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.09.2023.
//

import SwiftUI

struct ColorExampleView: View {
    var body: some View {
        VStack {
            HStack {
                Color.blue
                Color.cyan
                Color.indigo
                Color.clear
                Rectangle().fill(Color.cyan.gradient)
            }
            .frame(height: 100)
            
            HStack(spacing: 0) {
                ImageSelectionView(imageName: "dog_1",
                                   isSelected: false)
                ImageSelectionView(imageName: "cat_1",
                                   isSelected: true)
                ImageSelectionView(imageName: "horse_1",
                                   isSelected: false)
            }
        }
    }
}

fileprivate struct ImageSelectionView: View {
    let imageName: String
    let isSelected: Bool
    var body: some View {
        ResizableImageView(imageName: imageName)
            .overlay(alignment: .bottomTrailing) {
                if isSelected {
                    ZStack(alignment: .bottomTrailing) {
                        Color(white: 1, opacity: 0.5)
                        Image(systemName: "checkmark.circle.fill")
                            .foregroundColor(.accentColor)
                            .padding(1)
                            .background(Color.white, in: Circle())
                            .padding()
                    }
                }
            }
    }
}

#Preview {
    ColorExampleView()
}


