//
//  OverlayExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.09.2023.
//

import SwiftUI

struct OverlayExampleView: View {
    var body: some View {
        VStack {

            ResizableImageView(imageName: "cat_1")
                .overlay(alignment: .bottomLeading) {
                    Text("Cats are awesome")
                        .font(.title).bold()
                        .background(Color.white)
                        .padding()
                }
            HStack {
                VStack(alignment: .leading, spacing: 20) {
                    Text("First")
                        .border(Color.yellow)
                    Text("Second View")
                        .border(Color.orange)
                    Text("Third View")
                        .border(Color.red)
                }
                .overlay(alignment: .leading) {
                    Color.blue
                        .frame(width: 1)
                }
                
                VStack(alignment: .center, spacing: 20) {
                    Text("First")
                        .border(Color.yellow)
                    Text("Second View")
                        .border(Color.orange)
                    Text("Third View")
                        .border(Color.red)
                }
                .overlay(alignment: .center) {
                    Color.blue
                        .frame(width: 1)
                }
                
                VStack(alignment: .trailing, spacing: 20) {
                    Text("First")
                        .border(Color.yellow)
                    Text("Second View")
                        .border(Color.orange)
                    Text("Third View")
                        .border(Color.red)
                }
                .overlay(alignment: .trailing) {
                    Color.blue
                        .frame(width: 1)
                }
            }
        }
    }
}

struct  SpidermanProfileImage: View {
    var body: some View {
        Image("spiderman_profil")
            .resizable()
            .scaledToFill()
            .frame(width: 200, height: 200)
            .clipShape(Circle())
            .shadow(radius: 5)
            .overlay {
                Circle().stroke(Color.white, lineWidth: 5)
            }
           // .overlay(Color.white.opacity(0.5), in: Circle())
    }
}

#Preview {
    OverlayExampleView()
}


#Preview("Profile image") {
    SpidermanProfileImage()
}
