//
//  MovieDetailView.swift
//  LayoutProject
//
//  Created by Karin Prater on 03.09.2023.
//

import SwiftUI

struct MovieDetailView: View {
    
    let title: String
    let superhero = SuperHero.example
    let headerSpacing: CGFloat = 20
    
    var body: some View {
        VStack {
            ZStack(alignment: .movieAlignment) {
                ResizableImageView(imageName: "spider")
                
                HStack(spacing: 20) {
                    Image("spiderman_profil")
                        .resizable()
                        .scaledToFill()
                        .frame(maxWidth: 150, maxHeight: 200)
                        .clipShape(RoundedRectangle(cornerRadius: 5))
                    
                    VStack(alignment: .leading, spacing: headerSpacing) {
                        Text(title)
                            .font(.title)
                            .bold()
                            .lineLimit(2)
                            .foregroundColor(.white)
                            .alignmentGuide(.imageTitleAlignementGuide, computeValue: { dimension in
                                dimension[VerticalAlignment.bottom] + headerSpacing / 2
                            })
                        
                        VStack(alignment: .leading) {
                            Text("★★★★")
                            Text("Action")
                                .font(.headline)
                            Text("1h 51m")
                        }
                    }
                }
                .padding(.horizontal)
               
            }
            
            Text(superhero.biography)
                .padding()
            
            Spacer()
        }
    }
}

extension Alignment {
    static let movieAlignment = Alignment(horizontal: .leading,
                                          vertical: .imageTitleAlignementGuide)
}

#Preview("Short title") {
    MovieDetailView(title: "Spider-Man")
}

#Preview("Long Title") {
    MovieDetailView(title: "Spider-Man: No Way Home")
}
