//
//  UserInformationView.swift
//  LayoutProject
//
//  Created by Karin Prater on 03.09.2023.
//

import SwiftUI

struct UserInformationView: View {
    var body: some View {
        VStack(alignment: .customTrailing, spacing: 20) {
            Image(systemName: "person.fill.questionmark")
                .font(.system(size: 40))
                .foregroundStyle(.accent)
                .border(Color.black)
            
            PersonRowView(title: "Full Name:",
                          value: "John Doe")
            
            PersonRowView(title: "Street",
                          value: "One Apple Park Way")
            
            PersonRowView(title: "Zip",
                          value: "95014 Cupertino")
            
            PersonRowView(title: "Details", value: "")
        }
    }
}

fileprivate struct PersonRowView: View {
    let title: String
    let value: String
    
    var body: some View {
        HStack {
            Text(title)
                .border(Color.orange)
                .alignmentGuide(.customTrailing, computeValue: { dimension in
                    dimension[.trailing]
                })
            Text(value)
                .border(Color.yellow)
        }
    }
}

fileprivate struct CustomTrailing: AlignmentID {
    static func defaultValue(in context: ViewDimensions) -> CGFloat {
        context[.trailing]
    }
}

extension HorizontalAlignment {
    static let customTrailing: HorizontalAlignment = HorizontalAlignment(CustomTrailing.self)
}


#Preview {
    UserInformationView()
}


