//
//  VStackAlignmentGuideExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 03.09.2023.
//

import SwiftUI

struct VStackAlignmentGuideExampleView: View {
    var body: some View {
        VStack(spacing: 50) {
            HStack(alignment: .lastTextBaseline) {
                Text("Delicious")
                
                Image("avocado_large")
                    .border(Color.yellow)
                    .alignmentGuide(.lastTextBaseline, computeValue: { dimension in
                        dimension.height * 0.8
                    })
                
                Text("Avocado Toast")
                    .font(.largeTitle)
            }
            
            HStack(alignment: .lastTextBaseline) {
                Text("Delicious")
                
                Image("avocado_large")
                    .border(Color.yellow)
                    .alignmentGuide(.lastTextBaseline, computeValue: { dimension in
                        dimension.height  - 20
                    })
                
                Text("Avocado Toast")
                    .font(.largeTitle)
            }
            
            HStack(alignment: .lastTextBaseline) {
                Text("Delicious")
                
                Image("avocado_large")
                    .border(Color.yellow)
                    .alignmentGuide(.lastTextBaseline, computeValue: { dimension in
                        dimension[VerticalAlignment.top]
                    })
                
                Text("Avocado Toast")
                    .font(.largeTitle)
            }
            
            VStack(alignment: .leading) {
                
                Text("Moved")
                    .background {
                        HStack(spacing: 0) {
                            Color.pink
                            Color.orange
                            Color.yellow
                            Color.purple
                        }
                    }
                    .alignmentGuide(.leading, computeValue: { dimension in
                        dimension.width * 0.5
                    })
                
                Text("Delicious")
                    .border(Color.black)
                
                Image("avocado_large")
                    .alignmentGuide(.leading, computeValue: { dimension in
                        dimension.width * 0.5
                    })
            }
            
        }
    }
}

fileprivate struct ZStackAlignmentExampleView: View {
    var body: some View {
        VStack(alignment: .leading,spacing: 20) {
            ZStack(alignment: .bottomLeading) {
                ResizableImageView(imageName: "spider")
                
                SpidermanProfileImage()
                    .alignmentGuide(.bottom, computeValue: { dimension in
                        dimension.height * 0.5
                    })
                    .padding(.leading, 10)
                /*
                 .alignmentGuide(.leading, computeValue: { dimension in
                 dimension[.leading] - 10
                 })
                 */
            }
            
            Text("Additional information")
                .padding(.horizontal)
        }
    }
}

#Preview {
    VStackAlignmentGuideExampleView()
}

#Preview("ZStack") {
    ZStackAlignmentExampleView()
}
