//
//  DynamicDataContainerExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 18.10.23.
//

import SwiftUI

struct DynamicDataContainerExampleView: View {
    let inspirations = NatureInspiration.examples()
    
    var body: some View {
        CustomConainer(inspirations) { inspiration in
            Image(inspiration.imageName)
                .resizable()
                .scaledToFill()
        }
    }
}

struct CustomConainer<Data, RowContent>: View where Data: RandomAccessCollection, Data.Element : Identifiable, RowContent: View {
    
    private let data: [Data.Element]
    private let rowContent: (Data.Element) -> RowContent
    
    init(_ data: Data,
         @ViewBuilder rowContent: @escaping (Data.Element) -> RowContent) {
        self.data = data.map({ $0 })
        self.rowContent = rowContent
    }
    
    var body: some View {
        GeometryReader { geometry in
            List(data) { element in
                rowContent(element)
                    .frame(width: geometry.size.width,
                           height: geometry.size.width)
                    .clipped()
                    .listRowSeparator(.hidden)
                    .listRowInsets(.init(top: 0, leading: 0, bottom: 0, trailing: 0))
            }
            .listStyle(.plain)
        }
    }
}

fileprivate struct StartListView: View {
    
    let inspirations = NatureInspiration.examples()
    
    var body: some View {
        GeometryReader { geometry in
            List(inspirations) { inspiration in
                Image(inspiration.imageName)
                    .resizable()
                    .scaledToFill()
                    .frame(width: geometry.size.width,
                           height: geometry.size.width)
                    .clipped()
                    .listRowSeparator(.hidden)
                    .listRowInsets(.init(top: 0, leading: 0, bottom: 0, trailing: 0))
            }
            .listStyle(.plain)
        }
    }
}

#Preview {
    DynamicDataContainerExampleView()
}

#Preview("Starting point") {
    StartListView()
}
