//
//  ButtonStyleExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 18.10.23.
//

import SwiftUI

struct ButtonStyleExampleView: View {
    var body: some View {
        VStack {
            Button(action: {
                
            }, label: {
                Text("Button")
            })
            .buttonStyle(.borderedProminent)
            
            Button(action: {
                
            }, label: {
                Text("Button")
            })
            .buttonStyle(.borderedProminent)
            .disabled(true)
            
            Text("This is a text")
                .onTapGesture {
                    print("text was tapped")
                }
            
            
            Button(role: .destructive, action: {
                
            }, label: {
                Text("Button with  custom Style")
            })
            .buttonStyle(CustomButtonStyle())
            
            Button(role: .destructive, action: {
                
            }, label: {
                Text("Button with  custom Style")
            })
            .buttonStyle(CustomButtonStyle())
            .disabled(true)
            
        }
        .padding()
    }
}

struct CustomButtonStyle: ButtonStyle {
    
    @Environment(\.isEnabled) var isEnabled
    
    func makeBody(configuration: Configuration) -> some View {
        configuration.label
            .foregroundStyle(.white)
            .padding(.horizontal, 10)
            .padding(.vertical, 5)
            .frame(maxWidth: 400)
            .background {
                RoundedRectangle(cornerRadius: 5)
                    .fill(configuration.role == .destructive ? .pink : .accent)
                    .shadow(radius: shadow(for: configuration.isPressed))
            }
            .scaleEffect(CGSize(width: configuration.isPressed ? 0.9 : 1,
                                height: configuration.isPressed ? 0.9 : 1))
            .saturation(isEnabled ? 1 : 0)
        
    }
    
    func shadow(for isPressed: Bool) -> CGFloat {
        guard isEnabled else { return 2 }
        if  isPressed {
          return 0
        } else {
            return 5
        }
    }
}

#Preview {
    ButtonStyleExampleView()
}
