//
//  ViewModifierExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 18.10.23.
//

import SwiftUI

struct ViewModifierExampleView: View {
    var body: some View {
        VStack {
            HStack {
                Text("Hello, World!")
                    .foregroundStyle(.white)
                    .bold()
                    .padding()
                    .background(Color.cyan)
                
                Text("Hello, World!")
                    .modifier(BoxViewModifier())
                
                Text("Hello, World!")
                    .boxStyling()
            }
            
            ZStack {
                RoundedRectangle(cornerRadius: 25.0)
                    .fill(Color.cyan.gradient)
                Text("Content in a card view which is using a aspect ratio of one")
                    .padding()
            }
            .aspectRatio(1, contentMode: .fit)
            .padding()
            
            Text("Content in a card view which is using a aspect ratio of one")
                .squareBoxStyling()
                .padding()
            
           
        }
        .padding()
    }
}

fileprivate struct BoxViewModifier: ViewModifier {
    
    @Environment(\.horizontalSizeClass) var hori
    
    func body(content: Content) -> some View {
        content
            .foregroundStyle(.white)
            .bold()
            .padding(hori == .compact ? 10 : 30)
            .background(Color.pink)
    }
}

extension View {
    
    func boxStyling() -> some View {
        self.modifier(BoxViewModifier())
    }
    

}

extension Text {
    func squareBoxStyling() -> some View {
        ZStack {
            RoundedRectangle(cornerRadius: 25.0)
                .fill(Color.cyan.gradient)
            self
                .padding()
        }
        .aspectRatio(1, contentMode: .fit)
    }
}

extension Image {
    func resizeToFit(frameAspectRatio: CGFloat,
                     cornerRadius: CGFloat = 0) -> some View {
        Color.cyan
            .aspectRatio(frameAspectRatio, contentMode: .fit)
            .overlay {
                self.resizable()
                    .aspectRatio(nil, contentMode: .fill)
            }
            .clipped()
            .cornerRadius(cornerRadius)
    }
}

#Preview {
    ViewModifierExampleView()
}

#Preview("image") {
    VStack {
        ImageAspectView(imageName: "fish_3")
        
        Image("fish_3")
            .resizable()
            .scaledToFit()
        
        Image("fish_3")
            .resizeToFit(frameAspectRatio: 1)
    }
}
