//
//  PinnedHeadersScrollView.swift
//  LayoutProject
//
//  Created by Karin Prater on 11.11.23.
//

import SwiftUI

struct PinnedHeadersScrollView: View {
    
    let contacts = Contact.examples()
    let alphabet: Set<Character> = Set("ABCDEFGHIJKLMNOPQRSTUVWXYZ")
    
    var body: some View {
        NavigationStack {
            ScrollView {
                LazyVStack(alignment: .leading,
                           spacing: 10,
                           pinnedViews: [.sectionHeaders]) {
                    
                    ForEach(alphabet.sorted(), id: \.self) { letter in
                        Section {
                            ForEach(contacts.filter({ $0.name.first == letter }).sorted()) { contact in
                                NavigationLink(contact.name) {
                                    ContactDetailView(contact: contact)
                                }
                                .padding(.horizontal)
                            }
                        } header: {
                            Text(String(letter))
                                .font(.title)
                                .padding()
                                .frame(maxWidth: .infinity, alignment: .leading)
                                .background(.thinMaterial)
                        }
                        
                    }
                }
            }
            .navigationTitle("Contacts")
        }
    }
}

fileprivate struct ContactDetailView: View {
    let contact: Contact
    var body: some View {
        Text(contact.name)
    }
}

#Preview {
    PinnedHeadersScrollView()
}
