//
//  ScrollTargetBehaviorExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 07.11.23.
//

import SwiftUI

struct ScrollTargetBehaviorExampleView: View {
    let inspirations = NatureInspiration.examples()
    @State private var id: UUID? = nil
    
    var body: some View {
        VStack {
            ScrollView(.horizontal) {
                LazyHStack(spacing: 0) {
                    ForEach(inspirations) { inspiration in
                        InspirationCard(inspiration: inspiration)
                            .padding()
                            .containerRelativeFrame(.horizontal)
                        
                    }
                }
                .scrollTargetLayout()
            }
            .scrollTargetBehavior(.paging)
            .scrollPosition(id: $id)
            .scrollIndicators(.hidden)
            .fixedSize(horizontal: false, vertical: true)
            // .background(Color.black)
            .onAppear {
                id = inspirations.first?.id
            }
            
            HStack {
                ForEach(inspirations) { inspiration in
                  Circle()
                        .foregroundStyle(inspiration.id == id ? Color.black : Color(white: 0.7))
                        .frame(width: 10)
                }
            }
        }
    }
}

fileprivate struct ViewBasedScrollContainerRelativeFrameExampleView: View {
    let inspirations = NatureInspiration.examples()
    let padding: CGFloat = 10
    let imageSize: CGFloat = 100
    
    var rows: [GridItem] {
        Array(repeating: GridItem(.fixed(imageSize)), count: 3)
    }
    
    var body: some View {
        ScrollView(.horizontal) {
            LazyHGrid(rows: rows, spacing: padding) {
                ForEach(inspirations) { inspiration in
                    InspirationRowView(inspiration: inspiration,
                                       imageSize: imageSize)
                    .containerRelativeFrame(.horizontal) { length, axis in
                        length - padding * 2 - imageSize * 0.5
                    }
                }
            }
            .padding(padding)
            .scrollTargetLayout()
        }
        .scrollTargetBehavior(.viewAligned)
    }
}

#Preview("Paging") {
    ScrollTargetBehaviorExampleView()
}

#Preview("View Based", body: {
    ViewBasedScrollContainerRelativeFrameExampleView()
})
