//
//  DoubleScrollExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 07.11.23.
//

import SwiftUI

struct DoubleScrollExampleView: View {
    let inspirations = NatureInspiration.examples()
    @State private var id: UUID? = nil
    
    var body: some View {
        VStack {
            ScrollView(.horizontal) {
                LazyHStack(spacing: 0) {
                    ForEach(inspirations) { inspiration in
                        ImageAspectView(imageName: inspiration.imageName, frameAspectRatio: 1.5)
                            .containerRelativeFrame(.horizontal)
                        
                    }
                }
                .scrollTargetLayout()
                
            }
            .scrollTargetBehavior(.paging)
            .scrollPosition(id: $id)
            .scrollIndicators(.hidden)
            .fixedSize(horizontal: false, vertical: true)
            .onAppear {
                id = inspirations.first?.id
            }
            
            ScrollView {
                LazyVGrid(columns: [GridItem(.adaptive(minimum: 100),
                                             spacing: 5)],
                          alignment: .center,
                          spacing: 5, content: {
                    ForEach(inspirations) { inspiration in
                        ImageAspectView(imageName: inspiration.imageName, frameAspectRatio: 1.2)
                            .overlay {
                                Group {
                                    if inspiration.id == self.id {
                                        Color(white: 1, opacity: 0.5)
                                        Rectangle().stroke(Color.white, lineWidth: 5)
                                            
                                    }
                                }
                                .padding(2.5)
                            }
                            .onTapGesture {
                                withAnimation {
                                    id = inspiration.id
                                }
                               
                            }
                    }
                })
                
            }
           
        }
        .background(Color.black)
    }
}

#Preview {
    DoubleScrollExampleView()
}
