//
//  ScrollPositionExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 07.11.23.
//

import SwiftUI

struct ScrollPositionExampleView: View {
    let emojis = Emoji.examples()
    @State private var scrollID: Int? = nil
    
    var body: some View {
        ScrollView {
            LazyVStack {
                ForEach(emojis) { emoji in
                    GroupBox {
                        Text(emoji.emojiSting)
                            .font(.title)
                        Text("\(emoji.value)")
                            .frame(maxWidth: .infinity)
                    }
                }
                
                Button("Finish") {
                    
                }
                .buttonStyle(.borderedProminent)
                .id(1)
            }
            .padding()
            .scrollTargetLayout()
        }
        .scrollPosition(id: $scrollID, anchor: .center)
        .overlay {
            CrossHairView()
        }
        
        .background(Color.indigo)
        .safeAreaInset(edge: .bottom, content: {
            VStack {
                Text("Scroll Postion \(scrollID ?? 0)")
                    .font(.title).bold()
                
                HStack {
                    Button(action: {
                        withAnimation(.easeInOut(duration: 2)) {
                            scrollID = 128545
                        }
                        
                    }, label: {
                        Text("scroll to 😡")
                    })
                    .buttonStyle(.borderedProminent)
                    
                    Button(action: {
                        withAnimation(.easeInOut(duration: 2)) {
                            scrollID = 1
                        }
                        
                    }, label: {
                        Text("scroll to bottom")
                    })
                    .buttonStyle(.bordered)
                }
            }
            .frame(maxWidth: .infinity)
            .padding()
            .background(.thinMaterial)
            
        })
     
    }
}

#Preview {
    ScrollPositionExampleView()
}
