//
//  SyncTwoScrollViewsExample.swift
//  LayoutProject
//
//  Created by Karin Prater on 07.11.23.
//

import SwiftUI

struct SyncTwoScrollViewsExample: View {
    
    let inspirations = NatureInspiration.examples()
    @State private var topSelectedImage:NatureInspiration? = nil
    @State private var bottomSelectedImage:NatureInspiration? = nil
    
    let numberOfColumns = 3
    
    var body: some View {
        VStack {
            ScrollView(.horizontal) {
                LazyHStack(spacing: 0) {
                    ForEach(inspirations) { inspiration in
                        ImageAspectView(imageName: inspiration.imageName, frameAspectRatio: 1.5)
                            .containerRelativeFrame(.horizontal)
                            .id(inspiration)
                    }
                }
                .scrollTargetLayout()
            }
            .scrollTargetBehavior(.paging)
            .scrollPosition(id: $topSelectedImage)
            .scrollIndicators(.hidden)
            .fixedSize(horizontal: false, vertical: true)
            .onAppear {
                topSelectedImage = inspirations.first
                bottomSelectedImage = inspirations.first
            }
            
            ScrollView(.horizontal) {
                LazyHStack {
                    ForEach(inspirations) { inspiration in
                        ImageAspectView(imageName: inspiration.imageName, frameAspectRatio: 1.2)
                            .id(inspiration)
                            .overlay {
                                Group {
                                    if topSelectedImage == inspiration {
                                        Color(white: 1, opacity: 0.5)
                                        Rectangle().stroke(Color.white, lineWidth: 5).padding(2)
                                    }
                                }
                            }
                            .onTapGesture {
                                topSelectedImage = inspiration
                            }
                            .containerRelativeFrame(.horizontal,
                                                    count: numberOfColumns,
                                                    spacing: 10)
                    }
                }
                
            }
            .scrollTargetBehavior(.paging)
            .scrollPosition(id: $bottomSelectedImage)
            .scrollIndicators(.hidden)
            .fixedSize(horizontal: false, vertical: true)
            
        }
        .frame(maxHeight: .infinity, alignment: .top)
        .background(Color.black)
        .onChange(of: topSelectedImage) { oldValue, newValue in
            guard let newValue,
                  let topIndex = inspirations.firstIndex(of: newValue) else { return }
            
            let index = topIndex % numberOfColumns
            
            print("colum \(index)")
            
            if index == 0 {
                withAnimation {
                    self.bottomSelectedImage = newValue
                }
            } else if  index == numberOfColumns - 1 {
                withAnimation {
                    let leadingIndex = topIndex - numberOfColumns + 1
                    self.bottomSelectedImage = inspirations[leadingIndex]
                }
            }
            
            
        }
    }
}

#Preview {
    SyncTwoScrollViewsExample()
}
