//
//  BackgroundParallaxEffectView.swift
//  LayoutProject
//
//  Created by Karin Prater on 10.11.23.
//

import SwiftUI

struct BackgroundParallaxEffectView: View {
    let inspirations = NatureInspiration.examples()
    
    var body: some View {
    
        ScrollView(.horizontal) {
            HStack(spacing: 0) {
                ForEach(inspirations) { inspiration in
                    VStack {
                        Text(inspiration.name)
                            .font(.title)
                        Text(inspiration.description)
                            .multilineTextAlignment(.center)
                    }
                    .padding().padding(.vertical)
                    .containerRelativeFrame(.horizontal)
                }
            }
            .background(alignment: .leading) {
                Image(.abstractPoolWater)
                    .resizable()
                    .scaledToFill()
                    .containerRelativeFrame(.horizontal, { length, axis in
                        length * 2
                    })
                    .visualEffect { content, geometryProxy in
                        content.offset(x: imageOffset(for: geometryProxy), 
                                       y: 0)
                    }
            }
        }
        .scrollTargetBehavior(.paging)
    }
    
    func imageOffset(for proxy: GeometryProxy) -> CGFloat {
        let scrollPosition = proxy.bounds(of: .scrollView)?.minX ?? 0
        let offset = scrollPosition / CGFloat(inspirations.count - 1)
        return scrollPosition - offset
    }
}

#Preview {
    BackgroundParallaxEffectView()
}
