//
//  ParallaxEffectView.swift
//  LayoutProject
//
//  Created by Karin Prater on 10.11.23.
//

import SwiftUI

struct ParallaxEffectView: View {
    
    let inspirations = NatureInspiration.examples()
    var body: some View {
        
        ScrollView(.horizontal) {
            HStack(spacing: 0) {
                ForEach(inspirations) { inspiration in
                    VStack(spacing: 20) {
                        VStack {
                            Text(inspiration.name)
                                .font(.title)
                            Text(inspiration.description)
                                .font(.caption)
                                .multilineTextAlignment(.center)
                        }
                        .visualEffect { content, geometryProxy in
                            content.offset(x: textOffset(for: geometryProxy),
                                           y: 0)
                        }
                        
                        ImageAspectView(imageName: inspiration.imageName,
                                        frameAspectRatio: 2,
                                        cornerRadius: 0)
                        .padding(.horizontal, -70)
                        .visualEffect { content, geometryProxy in
                            content.offset(x: imageOffset(for: geometryProxy),
                                           y: 0)
                        }
                        .clipShape(RoundedRectangle(cornerRadius: 15))
                        .shadow(radius: 5)
                    }
                    .padding()
                    .containerRelativeFrame(.horizontal)
                }
            }
        }
        .scrollTargetBehavior(.paging)
    }
    
    func textOffset(for proxy: GeometryProxy) -> CGFloat {
        let scrollWidth = proxy.bounds(of: .scrollView)?.width ?? 100
        let cellOffset = proxy.frame(in: .scrollView).midX
        
        return (cellOffset - scrollWidth / 2) * 0.4
    }
    
    func imageOffset(for proxy: GeometryProxy) -> CGFloat {
        let scrollWidth = proxy.bounds(of: .scrollView)?.width ?? 100
        let cellOffset = proxy.frame(in: .scrollView).midX
        
        return (cellOffset - scrollWidth / 2) * 0.15
    }
}

#Preview {
    ParallaxEffectView()
}
