//
//  ScrollTransitionExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 10.11.23.
//

import SwiftUI

struct ScrollTransitionExampleView: View {
    let inspirations = NatureInspiration.examples()
    
    
    var body: some View {
        ScrollView {
            ForEach(inspirations) { inspiration in
                InspirationCard(inspiration: inspiration)
                    .scrollTransition { effect, phase in
                        effect
                            .scaleEffect(phase.isIdentity ? 1 : 0.9)
                            .opacity(phase.isIdentity ? 1 : 0)
                          //  .offset(x: offset(phase: phase), y: 0)
                            //.rotation3DEffect(angle(for: phase), axis: (x: 0, y: 1, z: 0))
                    }
            }
        }
        .contentMargins(10)
    }
    
    func offset(phase: ScrollTransitionPhase) -> CGFloat {
        /*
        switch phase {
            case .topLeading:
                return -50
            case .identity:
                return 0
            case .bottomTrailing:
                return 50
        }
        */
        return phase.value * 50
    }
    
    func angle(for phase: ScrollTransitionPhase) -> Angle {
        Angle(degrees: phase.value * 90)
    }
}

fileprivate struct HorizontalScrollTransitionExampleView: View {
    let inspirations = NatureInspiration.examples()
    @State private var scrollID: UUID? = nil
    
    var body: some View {
        VStack {
            ScrollView(.horizontal) {
                LazyHStack {
                    ForEach(inspirations) { inspiration in
                        InspirationCard(inspiration: inspiration,
                                        frameAspectRatio: 0.5)
                        .scrollTransition { effect, phase in
                            effect
                                .scaleEffect(phase.isIdentity ? 1 : 0.9)
                                .opacity(phase.isIdentity ? 1 : 0)
                            //  .offset(x: offset(phase: phase), y: 0)
                                .rotation3DEffect(angle(for: phase), axis: (x: 1, y: 0, z: 0), anchor: .top)
                        }
                        .containerRelativeFrame(.horizontal, count: 11, span: /*@START_MENU_TOKEN@*/3/*@END_MENU_TOKEN@*/, spacing: /*@START_MENU_TOKEN@*/10.0/*@END_MENU_TOKEN@*/)
                    }
                }
            }
            .contentMargins(10)
            
            ScrollView(.horizontal) {
                LazyHStack(spacing: 0) {
                    ForEach(inspirations) { inspiration in
                        InspirationCard(inspiration: inspiration,
                                        frameAspectRatio: 1.5)
                        .id(inspiration.id)
                        .scrollTransition { effect, phase in
                            effect
                               // .scaleEffect(phase.isIdentity ? 1 : 0.9)
                                .opacity(phase.isIdentity ? 1 : 0.5)
                                .scaleEffect(phase.isIdentity ? 0.95 : 1.05)
                            //  .offset(x: offset(phase: phase), y: 0)
                                .rotation3DEffect(Angle(degrees: phase.value * -15),
                                                  axis: (x: 0, y: 1, z: 0),
                                                  anchor: .center)
                        }
                        .containerRelativeFrame(.horizontal, count: 11, span: 8, spacing: /*@START_MENU_TOKEN@*/10.0/*@END_MENU_TOKEN@*/)
                    }
                }
            }
            .contentMargins(10)
            .scrollPosition(id: $scrollID, anchor: .center)
            .onAppear(perform: {
                scrollID = inspirations[1].id
            })
        }
    }
    
    func angle(for phase: ScrollTransitionPhase) -> Angle {
        Angle(degrees: (phase.isIdentity ? 0 : -15))
    }
}

#Preview {
    ScrollTransitionExampleView()
}

#Preview("horizontal") {
    HorizontalScrollTransitionExampleView()
}
