//
//  VisualEffectsExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 10.11.23.
//

import SwiftUI

struct VisualEffectsExampleView: View {
    var body: some View {
        ScrollView {
            ForEach(0..<100) { index in
                GroupBox {
                    Text("Row \(index)")
                        .frame(maxWidth: .infinity)
                }
                .groupBoxStyle(OrangeGroupBoxStyle())
                
                .visualEffect { content, geometryProxy in
                    content
                       // .offset(x: offset(for: geometryProxy),
                       //         y: 0)
                        .opacity(opacity(for: geometryProxy))
                        .scaleEffect(scaleAmount(for: geometryProxy))
                }
               
            }
        }
        .contentMargins(10)
        .overlay {
            CrossHairView()
        }
    }
    
    func offset(for proxy: GeometryProxy) -> CGFloat {
       // let cellHeight = proxy.size.height
        let scrollHeight = proxy.bounds(of: .scrollView)?.height ?? 100
        let cellOffset = proxy.frame(in: .scrollView).midY
        
        return cellOffset - scrollHeight / 2
    }
    
    func value(for proxy: GeometryProxy, scale: Double) -> Double {
        let scrollHeight = proxy.bounds(of: .scrollView)?.height ?? 100
        let cellOffset = proxy.frame(in: .scrollView).midY
        let distanceFromCenter = abs(scrollHeight / 2 - cellOffset)
        
        return 1 - Double(distanceFromCenter / scrollHeight * 2) * scale
    }
    
    func opacity(for proxy: GeometryProxy) -> Double {
        return value(for: proxy, scale: 0.6)
    }
    
    func scaleAmount(for proxy: GeometryProxy) -> CGSize {
        let value = value(for: proxy, scale: 0.1)
        return CGSize(width: value, height: value)
    }
}

fileprivate struct AnimatedLazyVGridExampleView: View {
    let emojis = Emoji.examples()
    
    var body: some View {
        ScrollView {
            LazyVGrid(columns: [GridItem(.adaptive(minimum: 80), spacing: 10)],
                      alignment: .center,
                      spacing: 10, content: {
                ForEach(emojis) {
                    EmojiView(emoji: $0)
                        .visualEffect { content, geometryProxy in
                            content
                                .opacity(opacity(for: geometryProxy))
                        }
                }
            })
            .padding()
        }
        .background(Color.black)
    }
    
    func value(for proxy: GeometryProxy, scale: Double) -> Double {
        let scrollHeight = proxy.bounds(of: .scrollView)?.height ?? 100
        let cellOffsetY = proxy.frame(in: .scrollView).midY
        let distanceFromCenterY = abs(scrollHeight / 2 - cellOffsetY)
        
        let scrollWidth = proxy.bounds(of: .scrollView)?.width ?? 100
        let cellOffsetX = proxy.frame(in: .scrollView).midX
        let distanceFromCenterX = abs(scrollWidth / 2 - cellOffsetX)
        
        return 1 - Double(distanceFromCenterX / scrollWidth) - Double(distanceFromCenterY / scrollHeight)
    }
    
    func opacity(for proxy: GeometryProxy) -> Double {
        return value(for: proxy, scale: 0.6)
    }
}

#Preview {
    VisualEffectsExampleView()
}

#Preview(body: {
    AnimatedLazyVGridExampleView()
})
