//
//  FixedSizeExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 10.09.2023.
//

import SwiftUI

struct FixedSizeExampleView: View {
    var body: some View {
        VStack {
            
            HStack {
                Text("Eat more")
                Image("avocado_large")
                Text("Avocado Toast")
                    .fixedSize()
            }
            .font(.title)
            .lineLimit(1)
            
            HStack {
                Color.cyan
                    .frame(height: 50)
                Text(Lorem.words(8))
                    .fixedSize()
                    .frame(width: 300, height: 50)
                    .border(/*@START_MENU_TOKEN@*/Color.black/*@END_MENU_TOKEN@*/)
            }
        }
    }
}

fileprivate struct EqualSizeExampleView: View {
    var body: some View {
        VStack {
            HStack {
                Text("short string")
                    .padding()
                    .background(Color.green)
                Text("There is not a lot of space to fit everything")
                    .padding()
                    .background(Color.red)
            }
            
            HStack {
                Text("short string")
                    .padding()
                    .frame(maxHeight: .infinity)
                    .background(Color.green)
                Text("There is not a lot of space to fit everything")
                    .padding()
                    .frame(maxHeight: .infinity)
                    .background(Color.red)
            }
            .fixedSize(horizontal: false, vertical: /*@START_MENU_TOKEN@*/true/*@END_MENU_TOKEN@*/)
            
            VStack {
                Text("short string")
                    .padding()
                    .frame(maxWidth: .infinity)
                    .background(Color.green)
                Text("Second view that is bigger")
                    .padding()
                    .frame(maxWidth: .infinity)
                    .background(Color.red)
            }
            .fixedSize(horizontal: true, vertical: false)
            
        }
        
    }
}

fileprivate struct UndefinedFixedSizeExampleView: View {
    var body: some View {
        VStack {
            Text("fixed size of a color")
            
            Color.indigo
                .fixedSize(horizontal: /*@START_MENU_TOKEN@*/true/*@END_MENU_TOKEN@*/, vertical: /*@START_MENU_TOKEN@*/true/*@END_MENU_TOKEN@*/)
            
            HStack(spacing: 0) {
                Text("Placeholder")
                    .background(Color.yellow)
                Color.indigo
                    .fixedSize()
                Text("Spacer")
                    .background(Color.yellow)
            }
            
            HStack(spacing: 0) {
                Text("Placeholder")
                    .background(Color.yellow)
                Spacer()
                    .fixedSize()
                Text("Spacer")
                    .background(Color.yellow)
            }
        }
    }
}

fileprivate struct ControlFixedSizeExampleView: View {
    var body: some View {
        VStack {
            ColorPicker("Select a color", selection: .constant(.red))
                .border(Color.red)
            
            
            ColorPicker("Select a color", selection: .constant(.red))
                .fixedSize()
                .border(Color.red)
            
            DatePicker("Pick a date", selection: .constant(Date()))
            
            DatePicker("Pick a date", selection: .constant(Date()))
                .fixedSize()
        }
    }
}



#Preview {
    FixedSizeExampleView()
}

#Preview("Equal size", body: {
    EqualSizeExampleView()
})

#Preview("No intrinsic size", body: {
    UndefinedFixedSizeExampleView()
})

#Preview("Control views") {
    ControlFixedSizeExampleView()
}
