//
//  SystemImageSizingView.swift
//  LayoutProject
//
//  Created by Karin Prater on 11.09.2023.
//

import SwiftUI

struct SystemImageSizingView: View {
    
    @ScaledMetric var size: CGFloat = 20
    
    var body: some View {
        VStack(spacing: 20) {
            Label("Swifty", systemImage: "swift")
                .foregroundColor(.orange)
               // .imageScale(.large)
            
            Image(systemName: "checkmark.circle")
                .foregroundStyle(.blue, .red)
            
            HStack {
                Image(systemName: "gear")
                    .font(/*@START_MENU_TOKEN@*/.title/*@END_MENU_TOKEN@*/)
                
                Image(systemName: "gear")
                    .font(.system(size: 20))
                Image(systemName: "gear")
                    .font(.system(size: 20))
                    .fontWeight(.black)
            }
            
            HStack {
                Image(systemName: "swift")
                    .imageScale(.small)
                Image(systemName: "swift")
                    .imageScale(.medium)
                Image(systemName: "swift")
                    .imageScale(.large)
            }
            
            HStack {
                Image(systemName: "lasso.badge.sparkles")
                    .font(/*@START_MENU_TOKEN@*/.title/*@END_MENU_TOKEN@*/)
                Image(systemName: "lasso.badge.sparkles")
                    .font(.system(size: 20))
                    .border(Color.yellow)
                
                Image(systemName: "lasso.badge.sparkles")
                    .resizable()
                    .frame(width: size, height: size)
                    .border(Color.yellow)
                
                Color.accentColor
                    .frame(width: 20, height: 20)
            }
        }
    }
}

fileprivate struct GroupedSystemImageExampleView: View {
    
    let icons = ["lasso.badge.sparkles", "square.and.arrow.up", "square.and.pencil.circle", "doc.on.doc", "pencil.tip", "line.diagonal.arrow", "arrow.up.left", "arrow.left"]
    
    var body: some View {
        HStack {
            VStack {
                ForEach(icons, id: \.self) { iconName in
                    Button(action: {
                        
                    }, label: {
                        Image(systemName: iconName)
                          //  .border(Color.red)
                    })
                    .buttonBorderShape(.circle)
                    .buttonStyle(.borderedProminent)
                }
            }
           
            VStack {
                ForEach(icons, id: \.self) { iconName in
                    Button(action: {
                        
                    }, label: {
                        Image(systemName: iconName)
                            .resizable()
                            .scaledToFill()
                            .frame(width: 16, height: 16)
                            .padding(2)
                            //.border(Color.red)
                            
                    })
                    .buttonBorderShape(.circle)
                    .buttonStyle(.borderedProminent)
                }
            }
            
            VStack {
                ForEach(icons, id: \.self) { iconName in
                    Button(action: {
                        
                    }, label: {
                        Image(systemName: iconName)
                            .resizable()
                            .scaledToFit()
                            .frame(width: 16, height: 16)
                            .padding(2)
                            //.border(Color.red)
                            
                    })
                    .buttonBorderShape(.circle)
                    .buttonStyle(.borderedProminent)
                }
            }
        }
    }
}

#Preview {
    SystemImageSizingView()
}

#Preview("Grouped Icons", body: {
    GroupedSystemImageExampleView()
})
