//
//  NoteEditView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct NoteEditView: View {
    
    @State private var note = Note.example()
    
    @State private var fontSize: CGFloat = 15
    @State private var isPresentingInspector = false
    
    var icon: String {
        #if os(macOS)
        "sidebar.trailing"
        #else
        "slider.horizontal.3"
        #endif
    }
    
    var body: some View {
        List {
            Section("title") {
                TextField("title", text: $note.title)
            }
            
            Section("Notes") {
                TextEditor(text: $note.content)
                    .font(.system(size: fontSize))
                    .frame(height: 50)
            }
            
            Toggle(isOn: $note.isFavorite) {
                Text("is Favourite")
            }
        }
        .inspector(isPresented: $isPresentingInspector) {
            EditorView(fontSize: $fontSize)
                .inspectorColumnWidth(min: 200, ideal: 400, max: 500)
        }
        .toolbar(content: {
            Toggle(isOn: $isPresentingInspector) {
                Label("Show Note Display Settings", systemImage: icon)
            }
        })
    }
}

fileprivate struct EditorView: View {
    
    @Binding var fontSize: CGFloat
    
    @State private var showLineNumbers = false
    @State private var showPreview = true
    
    var body: some View {
        Form {
            
            Slider(value: $fontSize) {
                Text("Point Size \(Int(fontSize))")
            }
            
            Section("Display") {
                Toggle(isOn: $showLineNumbers, label: {
                    Text("Show Line Numbers")
                })
                
                Toggle(isOn: $showPreview, label: {
                    Text("Show Preview")
                })
            }
        }
    }
}


#Preview {
    NavigationStack {
        NoteEditView()
    }
}
