//
//  SettingsIOSView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct SettingsIOSView: View {
    
    @State private var licenseKey: String = ""
    @AppStorage("selectedAppearance") var selectedAppearance = 0
    
    @State private var fontSize: CGFloat = 15
    @State private var showLineNumbers = false
    @State private var showPreview = true
    
    var body: some View {
        Form {
            
            Section("General") {
                LabeledContent("macOS Version", value: "2.2.1")
                    .bold()
                TextField("License Key", text: $licenseKey)
            }
            
            Picker(selection: $selectedAppearance) {
                Text("Default System")
                    .tag(0)
                Text("Light")
                    .tag(1)
                Text("Dark")
                    .tag(2)
                
            } label: {
                Text("Color Scheme")
            }
            .pickerStyle(.inline)
            
            Section {
                Slider(value: $fontSize, in: 10...40, step: 1) {
                    Text("Point Size \(Int(fontSize))")
                }
                .frame(maxWidth: 300)
                
                Toggle(isOn: $showLineNumbers, label: {
                    Text("Show Line Numbers")
                })
                
                Toggle(isOn: $showPreview, label: {
                    Text("Show Preview")
                })
            } header: {
                Text("Display")
                    .bold()
            } footer: {
                Text("How do you want to format your notes")
            }
            
        }
        .preferredColorScheme(colorScheme())
    }
    
    func colorScheme() -> ColorScheme? {
        if selectedAppearance == 1 {
           return ColorScheme.light
        } else if selectedAppearance == 2 {
            return ColorScheme.dark
        } else {
            return nil
        }
     }
}

#Preview {
    SettingsIOSView()
}
