//
//  FolderSelectionListView.swift
//  LayoutProject
//
//  Created by Karin Prater on 05.02.24.
//

import SwiftUI

enum FolderSelectionType: Hashable {
    case all
    case favourites
    case folder(Folder)
    
    var displayName: String {
        switch self {
            case .all:
                return "All Notes"
            case .favourites:
                return "Favourite Notes"
            case .folder(let folder):
                return folder.name
        }
    }
}

struct FolderSelectionListView: View {
    
    @Binding var folders: [Folder]
    @Binding var selection: FolderSelectionType?
    
    var body: some View {
        List(selection: $selection) {
            Section {
                Label("All Notes", systemImage: "rectangle.on.rectangle.circle.fill")
                    .tag(FolderSelectionType.all)
                Label("Favourites", systemImage: "heart.circle.fill")
                    .tag(FolderSelectionType.favourites)
            }
            
            Section("Your Folders") {
                ForEach(folders) { folder in
                    Label(folder.name, systemImage: "folder")
                        .tag(FolderSelectionType.folder(folder))
                }
            }
        }
    }
}

#Preview {
    struct PreviewFolderSelectionListView: View {
        @State private var folders = Folder.examples()
        @State private var selectionType: FolderSelectionType? = nil
        
        var body: some View {
            FolderSelectionListView(folders: $folders,
                                    selection: $selectionType)
        }
    }
    
    
    return PreviewFolderSelectionListView()
        
}
