//
//  NoteEditListView.swift
//  LayoutProject
//
//  Created by Karin Prater on 05.02.24.
//

import SwiftUI

struct NoteEditListView: View {
    
    @State private var notes: [Note] = Note.examples()
    
    var body: some View {
        
        NavigationStack {
            List {
                
                ForEach(notes) { note in
                    NoteRowView(note: note)
                        .contextMenu(ContextMenu(menuItems: {
                            Button(action: {
                                delete(note: note)
                            }, label: {
                                Label("Delete", systemImage: "trash")
                            })
                            Button(action: {
                                note.isFavorite.toggle()
                            }, label: {
                                Label("Favourite", systemImage: "heart.fill")
                            })
                        }))
                }
                .onDelete(perform: delete)
                .onMove(perform: move)
                
                // iOS 15, macOS 12
                Section("swipeAction") {
                    ForEach(notes) { note in
                        NoteRowView(note: note)
                            .swipeActions(edge: .trailing, allowsFullSwipe: false) {
                                Button(action: {
                                    delete(note: note)
                                }, label: {
                                    Label("Delete", systemImage: "trash")
                                })
                                .tint(.red)
                            }
                            .swipeActions(edge: .leading) {
                                Button(action: {
                                    note.isFavorite.toggle()
                                }, label: {
                                    Label("Favourite", systemImage: "heart.fill")
                                })
                                .tint(.pink)
                                
                                Button(action: {
                                   
                                }, label: {
                                    Label("Favourite", systemImage: "heart.fill")
                                })
                                .tint(.blue)
                            }
                        
                    }
                    .onDelete(perform: delete)
                }
               
                
                // iOS 16 macOs 13
                Section("editActions") {
                    ForEach($notes, editActions: [.move, .delete]) { $note in
                        NoteRowView(note: note)
                    }
                }
                
            }
            .navigationTitle("Note")
            
            #if os(iOS)
            .toolbar(content: {
                EditButton()
            })
            #endif
        }
    }
    
    func delete(at offset: IndexSet) {
        notes.remove(atOffsets: offset)
    }
    
    func delete(note: Note) {
        if let index = notes.firstIndex(of: note) {
            notes.remove(at: index)
        }
    }
    
    func move(from source: IndexSet, to destination: Int) {
        notes.move(fromOffsets: source, toOffset: destination)
    }
}

#Preview {
    NoteEditListView()
}
