//
//  NoteListView.swift
//  LayoutProject
//
//  Created by Karin Prater on 05.02.24.
//

import SwiftUI

struct NoteListView: View {
    @State private var notes: [Note] = Note.examples()
    
    var favoriteNotes: [Note] {
        notes.filter { $0.isFavorite }
    }
    
    var body: some View {
        NavigationStack {
            List {
                ForEach(notes) { note in
                    NoteRowView(note: note)
                }
                
                Section("Favorite Notes") {
                    ForEach(favoriteNotes) { note in
                        NoteRowView(note: note)
                    }
                }
            }
            .navigationTitle("Notes")
            .toolbar(content: {
                ToolbarItem(placement: .primaryAction) {
                    Button(action: {
                        notes.append(Note(title: "New Note"))
                    }, label: {
                        Label("Add New Note", systemImage: "plus")
                    })
                }
            })
            
            .safeAreaInset(edge: .bottom) {
                Button(action: {
                    notes.append(Note(title: "New Note"))
                }, label: {
                    Label("Add New Note", systemImage: "plus")
                })
                .padding()
                .frame(maxWidth: .infinity)
                #if os(iOS)
                .background(Color(.systemGroupedBackground))
                #endif
            }
        }
    }
}

#Preview {
    NoteListView()
}
