//
//  NoteSelectionListView.swift
//  LayoutProject
//
//  Created by Karin Prater on 05.02.24.
//

import SwiftUI

struct NoteSelectionListView: View {
    
    let notes: [Note]
    @Binding var selectedNote: Note?
    
    var body: some View {
        List(notes, selection: $selectedNote) { note in
            NoteRowView(note: note)
                .tag(note)
        }
    }
}

fileprivate struct NoteMultipleSelectionListView: View {
    
    let notes: [Note] = Note.examples()
    @State private var selectedNote: Set<Note> = []
    
    var body: some View {
        NavigationStack {
            List(selection: $selectedNote) {
                
                ForEach(notes){ note in
                    NoteRowView(note: note)
                        .tag(note)
                }
                #if os(iOS)
                EditListSubView(hasSelectedNotes: !selectedNote.isEmpty)
                #endif
            }
            #if os(iOS)
            .toolbar(content: {
                EditButton()
            })
            #endif
        }
    }
}

@available(macOS, unavailable)
fileprivate struct EditListSubView: View {
    @Environment(\.editMode) var editMode
    let hasSelectedNotes: Bool
    
    var body: some View {
        
        if editMode?.wrappedValue.isEditing == true && hasSelectedNotes {
            Section {
                Button(role: .destructive,
                       action: {
                    
                }, label: {
                    Label("Delete All", systemImage: "trash")
                })
                .foregroundColor(Color.red)
            }
        }
    }
}


#Preview("Single Selection") {
    struct PreviewNoteSelectionListView: View {
        let notes: [Note] = Note.examples()
        @State private var selectedNote: Note? = nil
        
        var body: some View {
            NoteSelectionListView(notes: notes,
                                  selectedNote: $selectedNote)
        }
    }
    
    return PreviewNoteSelectionListView()
}

#Preview("Multiple") {
    NoteMultipleSelectionListView()
}
