//
//  DisclosureListView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct DisclosureListView: View {
    let folders = Folder.examples()
    
    var body: some View {
        List {
            ForEach(folders) { folder in
                
                Section {
                    FolderSectionView(folder: folder,
                                      isInitiallyExpanded: folder == folders.first)
                }
            }
        }
    }
}

fileprivate struct FolderSectionView: View {
    
    let folder: Folder
    let isInitiallyExpanded: Bool
    
    @State private var isExpanded: Bool = false
    
    
    var body: some View {
        DisclosureGroup(
            isExpanded: $isExpanded,
            content: {
                ForEach(folder.notes) { note in
                    NoteRowView(note: note)
                }
            },
            label: {
                Label(folder.name, systemImage: "folder")
            }
        )
        .onAppear(perform: {
            isExpanded = isInitiallyExpanded
        })
    }
}


#Preview {
    DisclosureListView()
       
}
