//
//  TableEditView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct TableEditView: View {
    @State private var notes = Note.examples()
    
    var body: some View {
        
        Table(of: Note.self) {
            TableColumn("Title", value: \Note.title)
            TableColumn("Content", value: \Note.content)
            
            TableColumn("Created At") { note in
                Text(note.creationDate, style: .date)
            }
            
            TableColumn("Favorite") { note in
                Image(systemName: "heart")
                    .foregroundStyle(note.isFavorite ? Color.red : Color.clear)
            }
            
        } rows: {
            
            ForEach($notes) { $note in
                TableRow(note)
                    .contextMenu {
                        Toggle("Favorite", isOn: $note.isFavorite)
                        
                        Button(action: {
                            if let index = notes.firstIndex(of: note) {
                                notes.remove(at: index)
                            }
                            
                        }, label: {
                            Label("Delete", systemImage: "trash")
                        })
                        
                    }
            }
            
            TableRow(Note(title: "Example"))
        }
    }
}

#Preview {
    TableEditView()
}
