//
//  TableSelectionView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct TableSelectionView: View {
    
    @State private var folders = Folder.examples()
    @State private var selectedFolder: Folder.ID? = nil
    
    var body: some View {
        NavigationSplitView {
            Table(folders, selection: $selectedFolder) {
             
                TableColumn("Title", value: \Folder.name)
                TableColumn("Created At") { folder in
                    Text(folder.creationDate, style: .date)
                }
                TableColumn("Notes") { folder in
                    Text(folder.notes.count, format: .number)
                }
                
            }
        } detail: {
            if let selectedFolder,
               let folder = folders.first(where: { $0.id == selectedFolder }){
                List(folder.notes) {
                    NoteRowView(note: $0)
                }
            }
        }
    }
}

fileprivate struct MultipleSelectionTableView: View {
    @State private var folders = Folder.examples()
    @State private var selectedFolders: Set<Folder.ID> = []
    
    var body: some View {
        Table(folders,
              selection: $selectedFolders) {
         
            TableColumn("Title", value: \Folder.name)
            TableColumn("Created At") { folder in
                Text(folder.creationDate, style: .date)
            }
            TableColumn("Notes") { folder in
                Text(folder.notes.count, format: .number)
            }
            
        }
    }
}


#Preview("Single Selection") {
    TableSelectionView()
}

#Preview("Multiple Rows") {
    MultipleSelectionTableView()
}
