//
//  TableSortingExampleView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct TableSortingExampleView: View {
    
    @State private var notes = Note.examples()
    @State private var filteredNote = [Note]()
    
    @State private var searchText = ""
    @State private var sortOrders = [KeyPathComparator(\Note.title, order: .reverse)]
    
    var body: some View {
        Table(filteredNote, sortOrder: $sortOrders) {
            TableColumn("") { note in
                Circle().fill(note.colorTag)
                    .frame(width: 10)
            }
            .width(20)
            
            TableColumn("Title", value: \Note.title)
            TableColumn("Content", value: \Note.content)
            
            TableColumn("Created At", 
                        value: \Note.creationDate) { note in
                Text(note.creationDate, style: .date)
            }
            
            TableColumn("Favorite",
                        value: \Note.isFavoriteFormatted) { note in
                Image(systemName: "heart")
                    .foregroundStyle(note.isFavorite ? Color.red : Color.clear)
            }
        }
        .onAppear {
            filteredNote = notes
        }
        .onChange(of: sortOrders) { oldValue, newValue in
            filteredNote.sort(using: newValue)
        }
        .onChange(of: searchText, { oldValue, newValue in
            guard !newValue.isEmpty else {
                filteredNote = notes
                return
            }
            
            self.filteredNote = notes.filter({ $0.title.contains(newValue)})
        })
        .searchable(text: $searchText)
    }
}

#Preview {
    TableSortingExampleView()
}
