//
//  TableStylingView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct TableStylingView: View {
    let notes = Note.examples()
    
    @State private var selectedNote: Note.ID? = nil
    
    var body: some View {
        
        Table(notes, selection: $selectedNote) {
            
            TableColumn("") { note in
                Circle().fill(note.colorTag)
                    .frame(width: 10)
            }
            .width(20)
            
            
            TableColumn("Title", value: \Note.title)
            TableColumn("Content", value: \Note.content)
            
            TableColumn("Created At") { note in
                Text(note.creationDate, style: .date)
            }
            
            TableColumn("Favorite") { note in
                Image(systemName: note.isFavorite ? "heart.fill" : "heart")
                    .foregroundStyle(FavoriteShapeStyle())
            }
            .width(min: 20, ideal: 40, max: 80)
        }
        .tableColumnHeaders(.hidden)
       // .scrollDisabled(true)
    }
}

struct FavoriteShapeStyle: ShapeStyle {
    func resolve(in environment: EnvironmentValues) -> some ShapeStyle {
        if environment.backgroundProminence == .increased {
            return AnyShapeStyle(.secondary)
        } else {
            return AnyShapeStyle(.pink)
        }
    }
}


#Preview {
    TableStylingView()
    #if os(macOS)
        .tableStyle(.bordered)
        .alternatingRowBackgrounds(.disabled)
    
        //.tableStyle(.bordered(alternatesRowBackgrounds: false))
    #endif
}

#Preview {
    TableStylingView()
        .tableStyle(.inset)
}
