//
//  MarvelView.swift
//  LayoutProject
//
//  Created by Karin Prater on 30.08.2023.
//

import SwiftUI

struct MarvelView: View {
    
    let superHero: SuperHero
    
    @Environment(\.dynamicTypeSize) var dynamicTypeSize
    
    var body: some View {
        ZStack(alignment: .bottom) {
          
            Image(superHero.imageName)
                .renderingMode(.template)
                .resizable()
                .scaledToFit()
                .foregroundStyle(LinearGradient(colors: [Color.white, Color.black],
                                                startPoint: .top,
                                                endPoint: .bottomLeading))
             
                .frame(maxWidth: .infinity, maxHeight: 600, alignment: .topTrailing)
                .frame(maxHeight: .infinity, alignment: .top)
                .background(Color.black.gradient)
            
            ScrollView {
                VStack(alignment: .leading, spacing: 10) {
                    Text(superHero.name)
                        .font(.largeTitle)
                        .bold()
                    
                    Text("Biography")
                        .bold()
                        .padding(.top)
                    Text(superHero.biography)
                    
                    Text("Quotes")
                        .bold()
                        .padding(.top)
                    
                    VStack(alignment: .leading) {
                        ForEach(Array(superHero.quotes.enumerated()), id: \.offset) { (index, quote) in
                            Text(quote)
                                .italic()
                                .padding(15)
                                .background(.ultraThinMaterial)
                                .cornerRadius(5)
                                .applyIf(!dynamicTypeSize.isAccessibilitySize) {
                                    $0.padding(index.isOdd ? .leading : .trailing,
                                               50)
                                    .frame(maxWidth: .infinity,
                                           alignment: index.isOdd ? .trailing : .leading)
                                }
                        }
                    }
                    .applyIf(!dynamicTypeSize.isAccessibilitySize) {
                        $0.padding(.leading)
                    }
                }
                .foregroundStyle(.white)
                .padding()
                .padding(.top, 200)
            }
            .frame(maxWidth: 600)
        }
    }
}

extension Int {
    var isEven: Bool {
        return self % 2 == 0
    }

    var isOdd: Bool {
        return self % 2 != 0
    }
}


#Preview("Spiderman") {
    MarvelView(superHero: SuperHero.example)
}

#Preview("Iron Man") {
    MarvelView(superHero: SuperHero.example2)
}
