//
//  NoteSelectionGridView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct NoteSelectionGridView: View {
    let notes: [Note]
    @Binding var selectedNote: Note?
    
    var body: some View {
        ScrollView {
            LazyVGrid(columns: [GridItem(.adaptive(minimum: 150, maximum: 300), alignment: .top)], content: {
                ForEach(notes) { note in
                    VStack(alignment: .leading) {
                        Text(note.title)
                            .font(.title3)
                        Text(note.creationDate, style: .date)
                            .font(.caption)
                        
                        Divider()
                        Text(note.content)
                        
                    }
                    .frame(maxWidth: .infinity, alignment: .leading)
                    .padding()
                    .background(
                        RoundedRectangle(cornerRadius: 15)
                            .fill(Color.white)
                            .stroke(selectedNote == note ? Color.accentColor : Color.clear, lineWidth: 1)
                            .shadow(radius: 5))
                    .onTapGesture {
                        selectedNote = note
                    }
                }
            })
        }
        .contentMargins(15)
        
    }
}

#Preview {
    
    struct PreviewNoteSelectionGridView: View {
        @State var notes: [Note] = Note.examples()
        @State var selection: Note? = nil
        var body: some View {
            NoteSelectionGridView(notes: notes,
                                  selectedNote: $selection)
        }
    }
    
   return PreviewNoteSelectionGridView()
        .frame(minWidth: 400, minHeight: 300)
}
