//
//  NoteSelectionTableView.swift
//  LayoutProject
//
//  Created by Karin Prater on 06.02.24.
//

import SwiftUI

struct NoteSelectionTableView: View {
    let notes: [Note]
    @Binding var selectedNote: Note?
    @State private var selection: Note.ID? = nil
    
    var body: some View {
        Table(notes, selection: $selection) {
            TableColumn("Title", value: \.title)
            TableColumn("Note", value: \.content)
            TableColumn("Created at") { note in
                Text(note.creationDate, style: .date)
            }
            .width(200)
            
            TableColumn("is Favourite") { note in
                Image(systemName: "heart.fill")
                    .foregroundStyle(note.isFavorite ? Color.accentColor : Color.clear)
            }
            .width(100)
        }
        .onAppear {
            selection = selectedNote?.id
        }
        .onChange(of: selection) { oldValue, newValue in
            guard oldValue != newValue else { return }
            
            selectedNote = notes.first(where: { $0.id == newValue })
        }
    }
}

#Preview {
    
    struct PreviewNoteSelectionTableView: View {
        @State var selection: Note? = nil
        var body: some View {
            NoteSelectionTableView(notes: Note.examples(),
                                   selectedNote: $selection)
        }
    }
    
   return PreviewNoteSelectionTableView()
        .frame(minWidth: 400, minHeight: 300)
}
