//
//  PetDetailView.swift
//  LayoutProject
//
//  Created by Karin Prater on 30.08.2023.
//

import SwiftUI

struct PetDetailView: View {
    
    let pet: Pet
    @Binding var favoriteImages: Set<String>
     
     var body: some View {
         ScrollView {
             VStack(alignment: .leading) {
                 ScrollView(.horizontal) {
                     LazyHStack(spacing: 1) {
                         ForEach(pet.images, id: \.self) { imageName in
                             Image(imageName)
                                 .resizable()
                                 .scaledToFit()
                                 .overlay(alignment: .topTrailing) {
                                     FavoritePetButton(imageName: imageName,
                                                       favoriteImages: $favoriteImages)
                                     .padding()
                                 }
                                 .scrollTransition { contentView, phase in
                                     contentView.opacity(phase.isIdentity ? 1 : 0.5)
                                 }
                         }
                     }
                     .scrollTargetLayout()
                 }
                 .scrollClipDisabled()
                 .scrollTargetBehavior(.viewAligned)
                 .contentMargins(-10, for: .scrollIndicators)
                 //.frame(height: 350)
                 .containerRelativeFrame(.vertical, { length, axis in
                     length * 0.4
                 })
                 .padding(.bottom)
                 .scrollIndicatorsFlash(onAppear: true)
                 
                 Text("Interesting Facts:")
                     .font(.title2)
                     .padding(.vertical, 10)
                 ForEach(pet.facts, id: \.self) { fact in
                     HStack(alignment: .firstTextBaseline, spacing: 5) {
                         Image(systemName: "circle.fill")
                             .scaleEffect(0.35)
                         Text(fact)
                     }
                 }
                
             }
             .padding([.horizontal, .bottom])
         }
         #if os(iOS)
         .navigationBarTitle(pet.type.rawValue.capitalized)
         #endif
     }
}

fileprivate struct FavoritePetButton: View {
    let imageName: String
    @Binding var favoriteImages: Set<String>
    
    var body: some View {
        Button {
            if favoriteImages.contains(imageName) {
                favoriteImages.remove(imageName)
            } else {
                favoriteImages.insert(imageName)
            }
        } label: {
            Image(systemName: "heart.fill")
                .foregroundColor(favoriteImages.contains(imageName) ? .accentColor : Color(white: 0.25))
                .imageScale(.large)
                .padding(7).padding(.top, 2)
                .background(Circle().fill(.thinMaterial))
                .cornerRadius(3.0)
                .shadow(radius: 2)
        }
    }
}

#Preview {
    NavigationView {
        PetDetailView(pet: Pet.example, favoriteImages: .constant(["cat_1"]))
    }
}
