//
//  PetPalGalleryView.swift
//  LayoutProject
//
//  Created by Karin Prater on 30.08.2023.
//

import SwiftUI

struct PetPalGalleryView: View {
    
    let pets: [Pet]
    @Binding var favoriteImages: Set<String>
    
    private let padding: CGFloat = 10
    private var columns: [GridItem] {
        Array(repeating: GridItem(.flexible(), spacing: padding), count: 2)
    }
    
    var body: some View {
        NavigationStack {
            ScrollView {
                LazyVGrid(columns: columns, spacing: padding) {
                    ForEach(pets, id: \.type) { pet in
                        NavigationLink(destination:
                                        PetDetailView(pet: pet,
                                                      favoriteImages: $favoriteImages)
                        ) {
                            ImageAspectView(imageName: pet.images.first ?? "", 
                                            cornerRadius: 15)
                        }
                    }
                }
                .padding(padding * 2)
            }
            .navigationTitle("Pet Gallery")
        }
    }
}

struct EmojiPetPalGalleryView: View {
   
   let pets: [Pet]
   @Binding var favoriteImages: Set<String>
   
   private let padding: CGFloat = 10
   private var columns: [GridItem] {
       Array(repeating: GridItem(.flexible(minimum: 100), spacing: padding), count: 2)
   }
   
   var body: some View {
       NavigationStack {
           ScrollView {
               LazyVGrid(columns: columns, spacing: padding) {
                   ForEach(pets, id: \.type) { pet in
                       NavigationLink(destination: PetDetailView(pet: pet, favoriteImages: $favoriteImages)) {
                           PetCardView(pet: pet)
                       }
                   }
               }
               .padding(padding * 2)
           }
           .navigationTitle("Pet Gallery")
       }
   }
}

fileprivate struct PetCardView: View {
   let pet: Pet
   var body: some View {
       ZStack {
           RoundedRectangle(cornerRadius: 15)
               .fill(Color.indigo.gradient)
               .shadow(radius: 5)
           VStack {
               Text(emoji(for: pet))
                   .font(.system(size: 100))
                   
               Text(pet.type.displayName)
                   .foregroundStyle(Color.white)
                   .font(.title)
                   .bold()
           }
           //.padding()
       }
       .aspectRatio(1, contentMode: .fill)
   }
   
   func emoji(for pet: Pet) -> String {
       switch pet.type {
           case .cat: "😸"
           case .dog: "🐶"
           case .fish: "🐠"
           case .horse: "🐴"
       }
   }
}


#Preview("Images") {
    PetPalGalleryView(pets: Pet.examples,
                      favoriteImages: .constant(["cat_1"]))
}

#Preview("Emojis") {
    EmojiPetPalGalleryView(pets: Pet.examples,
                      favoriteImages: .constant(["cat_1"]))
}
