//
//  FileItem.swift
//  LayoutProject
//
//  Created by Karin Prater on 05.02.24.
//

import Foundation
import Observation

@Observable class FileItem: Identifiable {
 
    var title: String
    let isFolder: Bool
    var children: [FileItem]? = nil
    let id = UUID()
    
    init(title: String, isFolder: Bool, children: [FileItem]? = nil) {
        self.title = title
        self.isFolder = isFolder
        self.children = children
    }

    static func preview() -> [FileItem] {
        [FileItem(title: "Inbox", isFolder: true,
                  children: [FileItem(title: "My first email", isFolder: false),
                             FileItem(title: "My second email", isFolder: false)]),
         FileItem(title: "Archived", isFolder: true,
                  children: [FileItem(title: "work", isFolder: true,
                                      children: [FileItem(title: "Next Task", isFolder: false)]),
                             FileItem(title: "personal", isFolder: true,
                                      children: [FileItem(title: "Your Subscription expired", isFolder: false)])]),
         FileItem(title: "Trash", isFolder: true)]
    }
}

extension FileItem: Hashable {
    static func == (lhs: FileItem, rhs: FileItem) -> Bool {
        lhs.id == rhs.id
    }
    
    func hash(into hasher: inout Hasher) {
        hasher.combine(id)
    }
}
