//
//  Folder.swift
//  LayoutProject
//
//  Created by Karin Prater on 03.02.24.
//

import Foundation
import Observation

@Observable class Folder: Identifiable {
  
    let id: UUID
    let creationDate: Date
    var name: String
    var notes: [Note]
    
    init(name: String, notes: [Note]) {
        self.name = name
        self.notes = notes
        self.id = UUID()
        self.creationDate = Date()
    }
    
    static func example() -> Folder {
        Folder(name: "Meeting Notes",
               notes: Note.examples())
    }
    
    static func examples() -> [Folder] {
        [Folder(name: "Meeting Notes",
                notes: Note.examples()),
         Folder(name: "App Ideas",
                notes: [Note(title: "Reminder app",
                             isFavorite: true,
                             content: "Some amazing features for a reminder app",
                             colorTag: .blue)])]
    }
}

extension Folder: Hashable, Equatable {
    static func == (lhs: Folder, rhs: Folder) -> Bool {
        lhs.id == rhs.id
    }
    
    func hash(into hasher: inout Hasher) {
        hasher.combine(id)
    }
}

