//
//  Note.swift
//  LayoutProject
//
//  Created by Karin Prater on 28.10.23.
//

import SwiftUI
import Observation

@Observable class Note: Identifiable {
    
    var title: String
    var isFavorite: Bool
    let creationDate: Date
    var colorTag: Color
    var content: String
    
    var isFavoriteFormatted: String {
        isFavorite ? "favorite" : "not"
    }
    
    init(title: String, 
         isFavorite: Bool = false,
         content: String = "",
         colorTag: Color = .accentColor) {
        self.title = title
        self.isFavorite = isFavorite
        self.content = content
        self.creationDate = Date()
        self.colorTag = colorTag
    }
    
    static func example() -> Note {
        Note(title: "Meeting Notes",
             content: "- Discuss project timeline\n- Assign tasks to team members\n- Set next meeting date")
    }
    
    static func example2() -> Note {
        Note(title: "This is an amazing Note",
             isFavorite: true,
             content: "- Discuss project timeline\n- Assign tasks to team members\n- Set next meeting date")
    }
    
    static func examples() -> [Note] {
        [
            Note(title: "Shopping List",
                 isFavorite: true,
                 content: "1. Milk\n2. Eggs\n3. Bread",
                 colorTag: .green),
            Note(title: "Meeting Agenda for Q4",
                 isFavorite: false,
                 content: "1. Project update\n2. Budget discussion\n3. Next steps",
                 colorTag: .cyan),
            Note(title: "Ideas",
                 isFavorite: true,
                 content: "1. Write a novel and inspire millions of people \n2. Start a podcast\n3. Learn a new language",
                 colorTag: .orange),
        ]
    }
}

extension Note: Comparable, Hashable {
    static func < (lhs: Note, rhs: Note) -> Bool {
        lhs.creationDate < rhs.creationDate
    }
    
    static func == (lhs: Note, rhs: Note) -> Bool {
        lhs.id == rhs.id
    }
    
    func hash(into hasher: inout Hasher) {
        hasher.combine(id)
    }
}
