//
//  Pet.swift
//  LayoutProject
//
//  Created by Karin Prater on 19.06.22.
//

import Foundation

enum PetType: String, CaseIterable {
    case cat
    case dog
    case horse
    case fish
    
    var displayName: String {
        switch self {
            case .cat:
                "Cats"
            case .dog:
                "Dogs"
            case .horse:
                "Horses"
            case .fish:
                "Fish"
        }
    }
}

struct Pet: Identifiable, Equatable {
    let type: PetType
    var votes: Int = 0
    let images: [String]
    let facts: [String]
    var id: String { type.rawValue }

    static var example = Pet(type: .cat,
                             votes: 25,
                             images: ["cat_1", "cat_2", "cat_3", "cat_4"],
                             facts: ["Cats have excellent night vision.", "Cats use their whiskers to measure openings."])
   
    static var examples: [Pet] = [
        Pet(type: .cat, 
            votes: 25,
            images: ["cat_1", "cat_2", "cat_3", "cat_4"],
            facts: ["Cats have excellent night vision.", "Cats use their whiskers to measure openings."]),
        Pet(type: .dog,
            votes: 11,
            images: ["dog_1", "dog_2", "dog_3", "dog_4"],
            facts: ["Dogs have an extraordinary sense of smell.", "Dogs are known for their loyalty."]),
        Pet(type: .fish,
            votes: 5,
            images: ["fish_1", "fish_2", "fish_3", "fish_4"],
            facts: ["Fish come in many shapes, sizes, and colors.", "Some fish can change their gender as they age."]),
        Pet(type: .horse,
            votes: 7,
            images: ["horse_1", "horse_2", "horse_3", "horse_4"],
            facts: ["Horses can sleep both lying down and standing up.", "Horses communicate through ear and tail movements."])
    ]
}

