//
//  PicsumPhoto.swift
//  LayoutProject
//
//  Created by Karin Prater on 28.08.2023.
//

import Foundation

struct PicsumPhoto: Codable, Identifiable, Hashable {
    let id: String
    let author: String
    let width: CGFloat
    let height: CGFloat
    let url: String
    let downloadUrl: String
    
    var aspectRatio: CGFloat {
        width / height
    }
    
    enum CodingKeys: String, CodingKey {
        case id, author, width, height, url
        case downloadUrl = "download_url"
    }
    
    init(from decoder: Decoder) throws {
        let container = try decoder.container(keyedBy: CodingKeys.self)
        id = try container.decode(String.self, forKey: .id)
        author = try container.decode(String.self, forKey: .author)
        width = try container.decode(CGFloat.self, forKey: .width)
        height = try container.decode(CGFloat.self, forKey: .height)
        url = try container.decode(String.self, forKey: .url)
        downloadUrl = try container.decode(String.self, forKey: .downloadUrl)
    }
    
    init(id: String, author: String, width: CGFloat, height: CGFloat, url: String, downloadUrl: String) {
        self.id = id
        self.author = author
        self.width = width
        self.height = height
        self.url = url
        self.downloadUrl = downloadUrl
    }
    
    static func example() -> PicsumPhoto {
        PicsumPhoto(id: "63",
                    author: "Justin Leibow",
                    width: 5000,
                    height: 2813,
                    url: "https://unsplash.com/photos/ZJsseAxEcqM",
                    downloadUrl: "https://picsum.photos/id/63/5000/2813")
    }
    
    static func example2() -> PicsumPhoto {
        PicsumPhoto(id: "75",
                    author: "Jassy Onyae",
                    width: 1999,
                    height: 2998,
                    url: "https://unsplash.com/photos/1gBUXhf0PtA",
                    downloadUrl: "https://picsum.photos/id/75/1999/2998")
    }

    static func example3() -> PicsumPhoto {
        PicsumPhoto(id: "56",
                    author: "Jassy Onyae",
                    width: 2880,
                    height: 1920,
                    url: "https://unsplash.com/photos/1gBUXhf0PtA",
                    downloadUrl: "https://picsum.photos/id/56/2880/1920")
    }
    
    static func example4() -> PicsumPhoto {
        PicsumPhoto(id: "58",
                    author: "Jassy Onyae",
                    width: 1280,
                    height: 853,
                    url: "https://unsplash.com/photos/1gBUXhf0PtA",
                    downloadUrl: "https://picsum.photos/id/58/1280/853")
    }
    
    
}

