//
//  CachheAsyncImage.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.11.23.
//

import SwiftUI

struct CacheAsyncImage<Content>: View where Content: View {
    
    private let url: URL?
    private let scale: CGFloat
    private let transaction: Transaction
    private let content: (AsyncImagePhase) -> Content
    
    init(
        url: URL?,
        scale: CGFloat = 1.0,
        transaction: Transaction = Transaction(),
        @ViewBuilder content: @escaping (AsyncImagePhase) -> Content
    ){
        self.url = url
        self.scale = scale
        self.transaction = transaction
        self.content = content
    }
    
    var body: some View{
        if let url, let cached = ImageCache[url] {
            let _ = print("cached: \(url.absoluteString)")
            content(.success(cached))
        }else{
            let _ = print("request: \(url?.absoluteString ?? "")")
            AsyncImage(
                url: url,
                scale: scale,
                transaction: transaction
            ){phase in
                cacheAndRender(phase: phase)
            }
        }
    }
    func cacheAndRender(phase: AsyncImagePhase) -> some View{
        if case .success (let image) = phase, let url {
            ImageCache[url] = image
        }
        return content(phase)
    }
}

fileprivate class ImageCache {
    
    struct ImageData {
        let image: Image
        let timeStamp: Date
    }
    
    static private var cache: [URL: ImageData] = [:]
    static private let maxCacheNumber = 10
    static subscript(url: URL) -> Image?{
        get{
            ImageCache.cache[url]?.image
        }
        set{
            if ImageCache.cache.count >= maxCacheNumber,
               let first = ImageCache.cache.sorted(by: { $0.value.timeStamp < $1.value.timeStamp }).first?.key {
                print("remove")
                    ImageCache.cache.removeValue(forKey: first)
            }
            
            if let newValue {
                ImageCache.cache[url] = ImageData(image: newValue, timeStamp: Date())
            }
        }
    }
}

