//
//  PicsumPhotoImage.swift
//  LayoutProject
//
//  Created by Karin Prater on 02.11.23.
//

import SwiftUI

struct PicsumPhotoImage: View {
    
    let photo: PicsumPhoto
    let aspectRatio: CGFloat
    @Environment(\.displayScale) var scale
    
    init(photo: PicsumPhoto, aspectRatio: CGFloat? = nil) {
        self.photo = photo
        self.aspectRatio = aspectRatio ?? photo.aspectRatio
    }
    
    var body: some View {
        GeometryReader(content: { geometry in
            CacheAsyncImage(url: url(in: geometry.size.width),
                       scale: 3,
                       transaction: .init(animation: .easeIn(duration: 0.4))) { phase in
                switch phase {
                    case .empty:
                        ZStack {
                            Color.gray
                            ProgressView()
                        }
                    case .success(let image):
                        image
                            .resizable()
                            .scaledToFit()
                    case .failure(let error):
                        Text(error.localizedDescription)
                        // use placeholder for production app
                    @unknown default:
                        fatalError()
                }
            }
        })
        .aspectRatio(aspectRatio, contentMode: .fit)
    }
    
    func url(in width: CGFloat) -> URL? {
        let imageWidth = Int(width * scale)
        let imageHeight = Int(width * scale / aspectRatio)
        let urlString = "https://picsum.photos/id/\(photo.id)/\(imageWidth)/\(imageHeight)"
        return URL(string: urlString)
    }
}





#Preview {
    PicsumPhotoImage(photo: PicsumPhoto.example2())
}
