//
//  InfinitePhotoLoader.swift
//  LayoutProject
//
//  Created by Karin Prater on 11.11.23.
//

import Foundation

class InfinitePhotoLoader: ObservableObject {
    
    @Published var photos: [PicsumPhoto] = [] 
    
    var page: Int
    let photosPerPage: Int
    
    @Published var isLoading = false
    
    init(page: Int = 1, photosPerPage: Int = 10) {
        self.page = page
        self.photosPerPage = photosPerPage
    }
    
    func loadImages() {
        
        guard !isLoading else { return }
        isLoading = true
        
        let urlString = "https://picsum.photos/v2/list?page=\(page)&limit=\(photosPerPage)"
        page += 1
        guard let url = URL(string: urlString) else { return }
        
        URLSession.shared.dataTask(with: url) { data, response, error in
            if let data,
                let photos = try? JSONDecoder().decode([PicsumPhoto].self, from: data){
                DispatchQueue.main.async {
                    self.photos.insert(contentsOf: photos, at: self.photos.count)
                    self.isLoading = false
                }
            }
        }.resume()
    }
}
